# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.21.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# admin_concurrent_record
from .wrappers import admin_put_admin_game_record_concurrent_handler_v1
from .wrappers import admin_put_admin_game_record_concurrent_handler_v1_async
from .wrappers import admin_put_admin_player_record_concurrent_handler_v1
from .wrappers import admin_put_admin_player_record_concurrent_handler_v1_async
from .wrappers import admin_put_game_record_concurrent_handler_v1
from .wrappers import admin_put_game_record_concurrent_handler_v1_async
from .wrappers import admin_put_player_public_record_concurrent_handler_v1
from .wrappers import admin_put_player_public_record_concurrent_handler_v1_async
from .wrappers import admin_put_player_record_concurrent_handler_v1
from .wrappers import admin_put_player_record_concurrent_handler_v1_async

# admin_game_binary_record
from .wrappers import admin_delete_game_binary_record_v1
from .wrappers import admin_delete_game_binary_record_v1_async
from .wrappers import admin_get_game_binary_record_v1
from .wrappers import admin_get_game_binary_record_v1_async
from .wrappers import admin_list_game_binary_records_v1
from .wrappers import admin_list_game_binary_records_v1_async
from .wrappers import admin_post_game_binary_presigned_urlv1
from .wrappers import admin_post_game_binary_presigned_urlv1_async
from .wrappers import admin_post_game_binary_record_v1
from .wrappers import admin_post_game_binary_record_v1_async
from .wrappers import admin_put_game_binary_recor_metadata_v1
from .wrappers import admin_put_game_binary_recor_metadata_v1_async
from .wrappers import admin_put_game_binary_record_v1
from .wrappers import admin_put_game_binary_record_v1_async

# admin_game_record
from .wrappers import admin_delete_game_record_handler_v1
from .wrappers import admin_delete_game_record_handler_v1_async
from .wrappers import admin_get_game_record_handler_v1
from .wrappers import admin_get_game_record_handler_v1_async
from .wrappers import admin_post_game_record_handler_v1
from .wrappers import admin_post_game_record_handler_v1_async
from .wrappers import admin_put_game_record_handler_v1
from .wrappers import admin_put_game_record_handler_v1_async
from .wrappers import list_game_records_handler_v1
from .wrappers import list_game_records_handler_v1_async

# admin_player_binary_record
from .wrappers import admin_delete_player_binary_record_v1
from .wrappers import admin_delete_player_binary_record_v1_async
from .wrappers import admin_get_player_binary_record_v1
from .wrappers import admin_get_player_binary_record_v1_async
from .wrappers import admin_list_player_binary_records_v1
from .wrappers import admin_list_player_binary_records_v1_async
from .wrappers import admin_post_player_binary_presigned_urlv1
from .wrappers import admin_post_player_binary_presigned_urlv1_async
from .wrappers import admin_post_player_binary_record_v1
from .wrappers import admin_post_player_binary_record_v1_async
from .wrappers import admin_put_player_binary_recor_metadata_v1
from .wrappers import admin_put_player_binary_recor_metadata_v1_async
from .wrappers import admin_put_player_binary_record_v1
from .wrappers import admin_put_player_binary_record_v1_async

# admin_player_record
from .wrappers import admin_bulk_get_player_records_by_user_i_ds_handler_v1
from .wrappers import admin_bulk_get_player_records_by_user_i_ds_handler_v1_async
from .wrappers import admin_bulk_put_player_records_by_key_handler_v1
from .wrappers import admin_bulk_put_player_records_by_key_handler_v1_async
from .wrappers import admin_delete_player_public_record_handler_v1
from .wrappers import admin_delete_player_public_record_handler_v1_async
from .wrappers import admin_delete_player_record_handler_v1
from .wrappers import admin_delete_player_record_handler_v1_async
from .wrappers import admin_get_player_public_record_handler_v1
from .wrappers import admin_get_player_public_record_handler_v1_async
from .wrappers import admin_get_player_record_handler_v1
from .wrappers import admin_get_player_record_handler_v1_async
from .wrappers import admin_get_player_record_size_handler_v1
from .wrappers import admin_get_player_record_size_handler_v1_async
from .wrappers import admin_get_player_records_handler_v1
from .wrappers import admin_get_player_records_handler_v1_async
from .wrappers import admin_post_player_public_record_handler_v1
from .wrappers import admin_post_player_public_record_handler_v1_async
from .wrappers import admin_post_player_record_handler_v1
from .wrappers import admin_post_player_record_handler_v1_async
from .wrappers import admin_put_player_public_record_handler_v1
from .wrappers import admin_put_player_public_record_handler_v1_async
from .wrappers import admin_put_player_record_handler_v1
from .wrappers import admin_put_player_record_handler_v1_async
from .wrappers import admin_put_player_records_handler_v1
from .wrappers import admin_put_player_records_handler_v1_async
from .wrappers import admin_retrieve_player_records
from .wrappers import admin_retrieve_player_records_async
from .wrappers import bulk_get_player_record_size_handler_v1
from .wrappers import bulk_get_player_record_size_handler_v1_async
from .wrappers import list_player_record_handler_v1
from .wrappers import list_player_record_handler_v1_async

# admin_record
from .wrappers import admin_bulk_get_admin_game_record_v1
from .wrappers import admin_bulk_get_admin_game_record_v1_async
from .wrappers import admin_bulk_get_admin_player_record_v1
from .wrappers import admin_bulk_get_admin_player_record_v1_async
from .wrappers import admin_delete_admin_game_record_v1
from .wrappers import admin_delete_admin_game_record_v1_async
from .wrappers import admin_delete_admin_player_record_v1
from .wrappers import admin_delete_admin_player_record_v1_async
from .wrappers import admin_get_admin_game_record_v1
from .wrappers import admin_get_admin_game_record_v1_async
from .wrappers import admin_get_admin_player_record_v1
from .wrappers import admin_get_admin_player_record_v1_async
from .wrappers import admin_list_admin_game_record_v1
from .wrappers import admin_list_admin_game_record_v1_async
from .wrappers import admin_list_admin_user_records_v1
from .wrappers import admin_list_admin_user_records_v1_async
from .wrappers import admin_post_admin_game_record_v1
from .wrappers import admin_post_admin_game_record_v1_async
from .wrappers import admin_post_player_admin_record_v1
from .wrappers import admin_post_player_admin_record_v1_async
from .wrappers import admin_put_admin_game_record_v1
from .wrappers import admin_put_admin_game_record_v1_async
from .wrappers import admin_put_admin_player_record_v1
from .wrappers import admin_put_admin_player_record_v1_async
from .wrappers import bulk_get_admin_player_record_by_user_ids_v1
from .wrappers import bulk_get_admin_player_record_by_user_ids_v1_async

# admin_tags
from .wrappers import admin_delete_tag_handler_v1
from .wrappers import admin_delete_tag_handler_v1_async
from .wrappers import admin_list_tags_handler_v1
from .wrappers import admin_list_tags_handler_v1_async
from .wrappers import admin_post_tag_handler_v1
from .wrappers import admin_post_tag_handler_v1_async

# concurrent_record
from .wrappers import put_game_record_concurrent_handler_v1
from .wrappers import put_game_record_concurrent_handler_v1_async
from .wrappers import put_player_public_record_concurrent_handler_v1
from .wrappers import put_player_public_record_concurrent_handler_v1_async
from .wrappers import put_player_record_concurrent_handler_v1
from .wrappers import put_player_record_concurrent_handler_v1_async

# plugin_config
from .wrappers import create_plugin_config
from .wrappers import create_plugin_config_async
from .wrappers import delete_plugin_config
from .wrappers import delete_plugin_config_async
from .wrappers import get_plugin_config
from .wrappers import get_plugin_config_async
from .wrappers import update_plugin_config
from .wrappers import update_plugin_config_async

# public_game_binary_record
from .wrappers import bulk_get_game_binary_record_v1
from .wrappers import bulk_get_game_binary_record_v1_async
from .wrappers import delete_game_binary_record_v1
from .wrappers import delete_game_binary_record_v1_async
from .wrappers import get_game_binary_record_v1
from .wrappers import get_game_binary_record_v1_async
from .wrappers import list_game_binary_records_v1
from .wrappers import list_game_binary_records_v1_async
from .wrappers import post_game_binary_presigned_urlv1
from .wrappers import post_game_binary_presigned_urlv1_async
from .wrappers import post_game_binary_record_v1
from .wrappers import post_game_binary_record_v1_async
from .wrappers import put_game_binary_record_v1
from .wrappers import put_game_binary_record_v1_async

# public_game_record
from .wrappers import delete_game_record_handler_v1
from .wrappers import delete_game_record_handler_v1_async
from .wrappers import get_game_record_handler_v1
from .wrappers import get_game_record_handler_v1_async
from .wrappers import get_game_records_bulk
from .wrappers import get_game_records_bulk_async
from .wrappers import post_game_record_handler_v1
from .wrappers import post_game_record_handler_v1_async
from .wrappers import put_game_record_handler_v1
from .wrappers import put_game_record_handler_v1_async

# public_player_binary_record
from .wrappers import bulk_get_my_binary_record_v1
from .wrappers import bulk_get_my_binary_record_v1_async
from .wrappers import bulk_get_other_player_public_binary_records_v1
from .wrappers import bulk_get_other_player_public_binary_records_v1_async
from .wrappers import bulk_get_player_public_binary_records_v1
from .wrappers import bulk_get_player_public_binary_records_v1_async
from .wrappers import delete_player_binary_record_v1
from .wrappers import delete_player_binary_record_v1_async
from .wrappers import get_player_binary_record_v1
from .wrappers import get_player_binary_record_v1_async
from .wrappers import get_player_public_binary_records_v1
from .wrappers import get_player_public_binary_records_v1_async
from .wrappers import list_my_binary_records_v1
from .wrappers import list_my_binary_records_v1_async
from .wrappers import list_other_player_public_binary_records_v1
from .wrappers import list_other_player_public_binary_records_v1_async
from .wrappers import post_player_binary_presigned_urlv1
from .wrappers import post_player_binary_presigned_urlv1_async
from .wrappers import post_player_binary_record_v1
from .wrappers import post_player_binary_record_v1_async
from .wrappers import put_player_binary_recor_metadata_v1
from .wrappers import put_player_binary_recor_metadata_v1_async
from .wrappers import put_player_binary_record_v1
from .wrappers import put_player_binary_record_v1_async

# public_player_record
from .wrappers import bulk_get_player_public_record_handler_v1
from .wrappers import bulk_get_player_public_record_handler_v1_async
from .wrappers import delete_player_record_handler_v1
from .wrappers import delete_player_record_handler_v1_async
from .wrappers import get_other_player_public_record_handler_v1
from .wrappers import get_other_player_public_record_handler_v1_async
from .wrappers import get_other_player_public_record_key_handler_v1
from .wrappers import get_other_player_public_record_key_handler_v1_async
from .wrappers import get_player_public_record_handler_v1
from .wrappers import get_player_public_record_handler_v1_async
from .wrappers import get_player_record_handler_v1
from .wrappers import get_player_record_handler_v1_async
from .wrappers import get_player_records_bulk_handler_v1
from .wrappers import get_player_records_bulk_handler_v1_async
from .wrappers import post_player_public_record_handler_v1
from .wrappers import post_player_public_record_handler_v1_async
from .wrappers import post_player_record_handler_v1
from .wrappers import post_player_record_handler_v1_async
from .wrappers import public_delete_player_public_record_handler_v1
from .wrappers import public_delete_player_public_record_handler_v1_async
from .wrappers import put_player_public_record_handler_v1
from .wrappers import put_player_public_record_handler_v1_async
from .wrappers import put_player_record_handler_v1
from .wrappers import put_player_record_handler_v1_async
from .wrappers import retrieve_player_records
from .wrappers import retrieve_player_records_async

# public_tags
from .wrappers import public_list_tags_handler_v1
from .wrappers import public_list_tags_handler_v1_async

# ttl_config
from .wrappers import delete_game_binary_record_ttl_config
from .wrappers import delete_game_binary_record_ttl_config_async
from .wrappers import delete_game_record_ttl_config
from .wrappers import delete_game_record_ttl_config_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelNativeUserBlockRequest
from ..models import ModelNativeUserBlockResponse
from ..models import RestapiErrorResponseV1

from ..operations.blocks import SyncNativeBlockedUser


@same_doc_as(SyncNativeBlockedUser)
def sync_native_blocked_user(
    body: List[ModelNativeUserBlockRequest],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """sync blocked user using server to server call to native first party server. (syncNativeBlockedUser)

    Sync blocked user using server to server call to native first party server.
    Supported platforms:
    ps5, ps4 and pspc : the default environment would be sp-int, can be override using psnEnv.
    psnEnv consist of sp-int (default), prod-qa, np

    Properties:
        url: /lobby/sync/namespaces/{namespace}/me/block

        method: PATCH

        tags: ["blocks"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[ModelNativeUserBlockRequest] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ModelNativeUserBlockResponse]

        400: Bad Request - RestapiErrorResponseV1 (Bad Request)

        401: Unauthorized - RestapiErrorResponseV1 (Unauthorized)

        403: Forbidden - RestapiErrorResponseV1 (Forbidden)

        500: Internal Server Error - RestapiErrorResponseV1 (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncNativeBlockedUser.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SyncNativeBlockedUser)
async def sync_native_blocked_user_async(
    body: List[ModelNativeUserBlockRequest],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """sync blocked user using server to server call to native first party server. (syncNativeBlockedUser)

    Sync blocked user using server to server call to native first party server.
    Supported platforms:
    ps5, ps4 and pspc : the default environment would be sp-int, can be override using psnEnv.
    psnEnv consist of sp-int (default), prod-qa, np

    Properties:
        url: /lobby/sync/namespaces/{namespace}/me/block

        method: PATCH

        tags: ["blocks"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[ModelNativeUserBlockRequest] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ModelNativeUserBlockResponse]

        400: Bad Request - RestapiErrorResponseV1 (Bad Request)

        401: Unauthorized - RestapiErrorResponseV1 (Unauthorized)

        403: Forbidden - RestapiErrorResponseV1 (Forbidden)

        500: Internal Server Error - RestapiErrorResponseV1 (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncNativeBlockedUser.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.models_match_ticket import ModelsMatchTicket
from ..models.models_team import ModelsTeam


class ModelsMatch(Model):
    """Models match (models.Match)

    Properties:
        backfill: (Backfill) OPTIONAL bool

        client_version: (ClientVersion) OPTIONAL str

        match_attributes: (MatchAttributes) OPTIONAL Dict[str, Any]

        pivot_id: (PivotID) OPTIONAL str

        region_preference: (RegionPreference) OPTIONAL List[str]

        server_name: (ServerName) OPTIONAL str

        teams: (Teams) OPTIONAL List[ModelsTeam]

        tickets: (Tickets) OPTIONAL List[ModelsMatchTicket]

        timestamp: (Timestamp) OPTIONAL str
    """

    # region fields

    backfill: bool  # OPTIONAL
    client_version: str  # OPTIONAL
    match_attributes: Dict[str, Any]  # OPTIONAL
    pivot_id: str  # OPTIONAL
    region_preference: List[str]  # OPTIONAL
    server_name: str  # OPTIONAL
    teams: List[ModelsTeam]  # OPTIONAL
    tickets: List[ModelsMatchTicket]  # OPTIONAL
    timestamp: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_backfill(self, value: bool) -> ModelsMatch:
        self.backfill = value
        return self

    def with_client_version(self, value: str) -> ModelsMatch:
        self.client_version = value
        return self

    def with_match_attributes(self, value: Dict[str, Any]) -> ModelsMatch:
        self.match_attributes = value
        return self

    def with_pivot_id(self, value: str) -> ModelsMatch:
        self.pivot_id = value
        return self

    def with_region_preference(self, value: List[str]) -> ModelsMatch:
        self.region_preference = value
        return self

    def with_server_name(self, value: str) -> ModelsMatch:
        self.server_name = value
        return self

    def with_teams(self, value: List[ModelsTeam]) -> ModelsMatch:
        self.teams = value
        return self

    def with_tickets(self, value: List[ModelsMatchTicket]) -> ModelsMatch:
        self.tickets = value
        return self

    def with_timestamp(self, value: str) -> ModelsMatch:
        self.timestamp = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "backfill"):
            result["Backfill"] = bool(self.backfill)
        elif include_empty:
            result["Backfill"] = False
        if hasattr(self, "client_version"):
            result["ClientVersion"] = str(self.client_version)
        elif include_empty:
            result["ClientVersion"] = ""
        if hasattr(self, "match_attributes"):
            result["MatchAttributes"] = {
                str(k0): v0 for k0, v0 in self.match_attributes.items()
            }
        elif include_empty:
            result["MatchAttributes"] = {}
        if hasattr(self, "pivot_id"):
            result["PivotID"] = str(self.pivot_id)
        elif include_empty:
            result["PivotID"] = ""
        if hasattr(self, "region_preference"):
            result["RegionPreference"] = [str(i0) for i0 in self.region_preference]
        elif include_empty:
            result["RegionPreference"] = []
        if hasattr(self, "server_name"):
            result["ServerName"] = str(self.server_name)
        elif include_empty:
            result["ServerName"] = ""
        if hasattr(self, "teams"):
            result["Teams"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.teams
            ]
        elif include_empty:
            result["Teams"] = []
        if hasattr(self, "tickets"):
            result["Tickets"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.tickets
            ]
        elif include_empty:
            result["Tickets"] = []
        if hasattr(self, "timestamp"):
            result["Timestamp"] = str(self.timestamp)
        elif include_empty:
            result["Timestamp"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        backfill: Optional[bool] = None,
        client_version: Optional[str] = None,
        match_attributes: Optional[Dict[str, Any]] = None,
        pivot_id: Optional[str] = None,
        region_preference: Optional[List[str]] = None,
        server_name: Optional[str] = None,
        teams: Optional[List[ModelsTeam]] = None,
        tickets: Optional[List[ModelsMatchTicket]] = None,
        timestamp: Optional[str] = None,
        **kwargs,
    ) -> ModelsMatch:
        instance = cls()
        if backfill is not None:
            instance.backfill = backfill
        if client_version is not None:
            instance.client_version = client_version
        if match_attributes is not None:
            instance.match_attributes = match_attributes
        if pivot_id is not None:
            instance.pivot_id = pivot_id
        if region_preference is not None:
            instance.region_preference = region_preference
        if server_name is not None:
            instance.server_name = server_name
        if teams is not None:
            instance.teams = teams
        if tickets is not None:
            instance.tickets = tickets
        if timestamp is not None:
            instance.timestamp = timestamp
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> ModelsMatch:
        instance = cls()
        if not dict_:
            return instance
        if "Backfill" in dict_ and dict_["Backfill"] is not None:
            instance.backfill = bool(dict_["Backfill"])
        elif include_empty:
            instance.backfill = False
        if "ClientVersion" in dict_ and dict_["ClientVersion"] is not None:
            instance.client_version = str(dict_["ClientVersion"])
        elif include_empty:
            instance.client_version = ""
        if "MatchAttributes" in dict_ and dict_["MatchAttributes"] is not None:
            instance.match_attributes = {
                str(k0): v0 for k0, v0 in dict_["MatchAttributes"].items()
            }
        elif include_empty:
            instance.match_attributes = {}
        if "PivotID" in dict_ and dict_["PivotID"] is not None:
            instance.pivot_id = str(dict_["PivotID"])
        elif include_empty:
            instance.pivot_id = ""
        if "RegionPreference" in dict_ and dict_["RegionPreference"] is not None:
            instance.region_preference = [str(i0) for i0 in dict_["RegionPreference"]]
        elif include_empty:
            instance.region_preference = []
        if "ServerName" in dict_ and dict_["ServerName"] is not None:
            instance.server_name = str(dict_["ServerName"])
        elif include_empty:
            instance.server_name = ""
        if "Teams" in dict_ and dict_["Teams"] is not None:
            instance.teams = [
                ModelsTeam.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["Teams"]
            ]
        elif include_empty:
            instance.teams = []
        if "Tickets" in dict_ and dict_["Tickets"] is not None:
            instance.tickets = [
                ModelsMatchTicket.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["Tickets"]
            ]
        elif include_empty:
            instance.tickets = []
        if "Timestamp" in dict_ and dict_["Timestamp"] is not None:
            instance.timestamp = str(dict_["Timestamp"])
        elif include_empty:
            instance.timestamp = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsMatch]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsMatch]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ModelsMatch, List[ModelsMatch], Dict[Any, ModelsMatch]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "Backfill": "backfill",
            "ClientVersion": "client_version",
            "MatchAttributes": "match_attributes",
            "PivotID": "pivot_id",
            "RegionPreference": "region_preference",
            "ServerName": "server_name",
            "Teams": "teams",
            "Tickets": "tickets",
            "Timestamp": "timestamp",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "Backfill": False,
            "ClientVersion": False,
            "MatchAttributes": False,
            "PivotID": False,
            "RegionPreference": False,
            "ServerName": False,
            "Teams": False,
            "Tickets": False,
            "Timestamp": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class CatalogTypeEnum(StrEnum):
    APP = "APP"
    CATEGORY = "CATEGORY"
    ITEM = "ITEM"
    SECTION = "SECTION"
    VIEW = "VIEW"


class ExportStoreToCSVRequest(Model):
    """Export store to CSV request (ExportStoreToCSVRequest)

    Properties:
        catalog_type: (catalogType) REQUIRED Union[str, CatalogTypeEnum]

        fields_to_be_included: (fieldsToBeIncluded) OPTIONAL List[str]

        ids_to_be_exported: (idsToBeExported) OPTIONAL List[str]

        store_id: (storeId) OPTIONAL str
    """

    # region fields

    catalog_type: Union[str, CatalogTypeEnum]  # REQUIRED
    fields_to_be_included: List[str]  # OPTIONAL
    ids_to_be_exported: List[str]  # OPTIONAL
    store_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_catalog_type(
        self, value: Union[str, CatalogTypeEnum]
    ) -> ExportStoreToCSVRequest:
        self.catalog_type = value
        return self

    def with_fields_to_be_included(self, value: List[str]) -> ExportStoreToCSVRequest:
        self.fields_to_be_included = value
        return self

    def with_ids_to_be_exported(self, value: List[str]) -> ExportStoreToCSVRequest:
        self.ids_to_be_exported = value
        return self

    def with_store_id(self, value: str) -> ExportStoreToCSVRequest:
        self.store_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "catalog_type"):
            result["catalogType"] = str(self.catalog_type)
        elif include_empty:
            result["catalogType"] = Union[str, CatalogTypeEnum]()
        if hasattr(self, "fields_to_be_included"):
            result["fieldsToBeIncluded"] = [
                str(i0) for i0 in self.fields_to_be_included
            ]
        elif include_empty:
            result["fieldsToBeIncluded"] = []
        if hasattr(self, "ids_to_be_exported"):
            result["idsToBeExported"] = [str(i0) for i0 in self.ids_to_be_exported]
        elif include_empty:
            result["idsToBeExported"] = []
        if hasattr(self, "store_id"):
            result["storeId"] = str(self.store_id)
        elif include_empty:
            result["storeId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        catalog_type: Union[str, CatalogTypeEnum],
        fields_to_be_included: Optional[List[str]] = None,
        ids_to_be_exported: Optional[List[str]] = None,
        store_id: Optional[str] = None,
        **kwargs,
    ) -> ExportStoreToCSVRequest:
        instance = cls()
        instance.catalog_type = catalog_type
        if fields_to_be_included is not None:
            instance.fields_to_be_included = fields_to_be_included
        if ids_to_be_exported is not None:
            instance.ids_to_be_exported = ids_to_be_exported
        if store_id is not None:
            instance.store_id = store_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ExportStoreToCSVRequest:
        instance = cls()
        if not dict_:
            return instance
        if "catalogType" in dict_ and dict_["catalogType"] is not None:
            instance.catalog_type = str(dict_["catalogType"])
        elif include_empty:
            instance.catalog_type = Union[str, CatalogTypeEnum]()
        if "fieldsToBeIncluded" in dict_ and dict_["fieldsToBeIncluded"] is not None:
            instance.fields_to_be_included = [
                str(i0) for i0 in dict_["fieldsToBeIncluded"]
            ]
        elif include_empty:
            instance.fields_to_be_included = []
        if "idsToBeExported" in dict_ and dict_["idsToBeExported"] is not None:
            instance.ids_to_be_exported = [str(i0) for i0 in dict_["idsToBeExported"]]
        elif include_empty:
            instance.ids_to_be_exported = []
        if "storeId" in dict_ and dict_["storeId"] is not None:
            instance.store_id = str(dict_["storeId"])
        elif include_empty:
            instance.store_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ExportStoreToCSVRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ExportStoreToCSVRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ExportStoreToCSVRequest,
        List[ExportStoreToCSVRequest],
        Dict[Any, ExportStoreToCSVRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "catalogType": "catalog_type",
            "fieldsToBeIncluded": "fields_to_be_included",
            "idsToBeExported": "ids_to_be_exported",
            "storeId": "store_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "catalogType": True,
            "fieldsToBeIncluded": False,
            "idsToBeExported": False,
            "storeId": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "catalogType": ["APP", "CATEGORY", "ITEM", "SECTION", "VIEW"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "4.56.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._achievement_platform import get_xbl_user_achievements
from ._achievement_platform import get_xbl_user_achievements_async
from ._achievement_platform import unlock_steam_user_achievement
from ._achievement_platform import unlock_steam_user_achievement_async
from ._achievement_platform import update_xbl_user_achievement
from ._achievement_platform import update_xbl_user_achievement_async

from ._anonymization import anonymize_campaign
from ._anonymization import anonymize_campaign_async
from ._anonymization import anonymize_entitlement
from ._anonymization import anonymize_entitlement_async
from ._anonymization import anonymize_fulfillment
from ._anonymization import anonymize_fulfillment_async
from ._anonymization import anonymize_integration
from ._anonymization import anonymize_integration_async
from ._anonymization import anonymize_order
from ._anonymization import anonymize_order_async
from ._anonymization import anonymize_payment
from ._anonymization import anonymize_payment_async
from ._anonymization import anonymize_revocation
from ._anonymization import anonymize_revocation_async
from ._anonymization import anonymize_subscription
from ._anonymization import anonymize_subscription_async
from ._anonymization import anonymize_wallet
from ._anonymization import anonymize_wallet_async

from ._campaign import apply_user_redemption
from ._campaign import apply_user_redemption_async
from ._campaign import bulk_disable_codes
from ._campaign import bulk_disable_codes_async
from ._campaign import bulk_enable_codes
from ._campaign import bulk_enable_codes_async
from ._campaign import create_campaign
from ._campaign import create_campaign_async
from ._campaign import create_codes
from ._campaign import create_codes_async
from ._campaign import disable_code
from ._campaign import disable_code_async
from ._campaign import download
from ._campaign import download_async
from ._campaign import enable_code
from ._campaign import enable_code_async
from ._campaign import get_campaign
from ._campaign import get_campaign_async
from ._campaign import get_campaign_dynamic
from ._campaign import get_campaign_dynamic_async
from ._campaign import get_code
from ._campaign import get_code_async
from ._campaign import query_campaign_batch_names
from ._campaign import query_campaign_batch_names_async
from ._campaign import query_campaigns
from ._campaign import query_campaigns_async
from ._campaign import query_codes
from ._campaign import query_codes_async
from ._campaign import query_redeem_history
from ._campaign import query_redeem_history_async
from ._campaign import rename_batch
from ._campaign import rename_batch_async
from ._campaign import update_campaign
from ._campaign import update_campaign_async

from ._catalog_changes import get_statistic
from ._catalog_changes import get_statistic_async
from ._catalog_changes import publish_all
from ._catalog_changes import publish_all_async
from ._catalog_changes import publish_selected
from ._catalog_changes import publish_selected_async
from ._catalog_changes import query_changes
from ._catalog_changes import query_changes_async
from ._catalog_changes import select_all_records
from ._catalog_changes import select_all_records_async
from ._catalog_changes import select_all_records_by_criteria
from ._catalog_changes import select_all_records_by_criteria_async
from ._catalog_changes import select_record
from ._catalog_changes import select_record_async
from ._catalog_changes import unselect_all_records
from ._catalog_changes import unselect_all_records_async
from ._catalog_changes import unselect_record
from ._catalog_changes import unselect_record_async

from ._category import create_category
from ._category import create_category_async
from ._category import delete_category
from ._category import delete_category_async
from ._category import download_categories
from ._category import download_categories_async
from ._category import get_category
from ._category import get_category_async
from ._category import get_child_categories
from ._category import get_child_categories_async
from ._category import get_descendant_categories
from ._category import get_descendant_categories_async
from ._category import get_root_categories
from ._category import get_root_categories_async
from ._category import list_categories_basic
from ._category import list_categories_basic_async
from ._category import public_get_category
from ._category import public_get_category_async
from ._category import public_get_child_categories
from ._category import public_get_child_categories_async
from ._category import public_get_descendant_categories
from ._category import public_get_descendant_categories_async
from ._category import public_get_root_categories
from ._category import public_get_root_categories_async
from ._category import update_category
from ._category import update_category_async

from ._clawback import mock_play_station_stream_event
from ._clawback import mock_play_station_stream_event_async
from ._clawback import query_iap_clawback_history
from ._clawback import query_iap_clawback_history_async

from ._currency import create_currency
from ._currency import create_currency_async
from ._currency import delete_currency
from ._currency import delete_currency_async
from ._currency import get_currency_config
from ._currency import get_currency_config_async
from ._currency import get_currency_summary
from ._currency import get_currency_summary_async
from ._currency import list_currencies
from ._currency import list_currencies_async
from ._currency import public_list_currencies
from ._currency import public_list_currencies_async
from ._currency import update_currency
from ._currency import update_currency_async

from ._dlc import delete_dlc_item_config
from ._dlc import delete_dlc_item_config_async
from ._dlc import delete_platform_dlc_config
from ._dlc import delete_platform_dlc_config_async
from ._dlc import ge_dlc_durable_reward_short_map
from ._dlc import ge_dlc_durable_reward_short_map_async
from ._dlc import get_dlc_item_config
from ._dlc import get_dlc_item_config_async
from ._dlc import get_platform_dlc_config
from ._dlc import get_platform_dlc_config_async
from ._dlc import get_user_dlc
from ._dlc import get_user_dlc_async
from ._dlc import get_user_dlc_by_platform
from ._dlc import get_user_dlc_by_platform_async
from ._dlc import public_get_my_dlc_content
from ._dlc import public_get_my_dlc_content_async
from ._dlc import public_sync_psn_dlc_inventory
from ._dlc import public_sync_psn_dlc_inventory_async
from ._dlc import public_sync_psn_dlc_inventory_with_multiple_service_labels
from ._dlc import public_sync_psn_dlc_inventory_with_multiple_service_labels_async
from ._dlc import sync_epic_game_dlc
from ._dlc import sync_epic_game_dlc_async
from ._dlc import sync_oculus_dlc
from ._dlc import sync_oculus_dlc_async
from ._dlc import sync_steam_dlc
from ._dlc import sync_steam_dlc_async
from ._dlc import sync_xbox_dlc
from ._dlc import sync_xbox_dlc_async
from ._dlc import update_dlc_item_config
from ._dlc import update_dlc_item_config_async
from ._dlc import update_platform_dlc_config
from ._dlc import update_platform_dlc_config_async

from ._entitlement import consume_user_entitlement
from ._entitlement import consume_user_entitlement_async
from ._entitlement import disable_user_entitlement
from ._entitlement import disable_user_entitlement_async
from ._entitlement import enable_entitlement_origin_feature
from ._entitlement import enable_entitlement_origin_feature_async
from ._entitlement import enable_user_entitlement
from ._entitlement import enable_user_entitlement_async
from ._entitlement import exists_any_user_active_entitlement
from ._entitlement import exists_any_user_active_entitlement_async
from ._entitlement import exists_any_user_active_entitlement_by_item_ids
from ._entitlement import exists_any_user_active_entitlement_by_item_ids_async
from ._entitlement import get_entitlement
from ._entitlement import get_entitlement_async
from ._entitlement import get_entitlement_config_info
from ._entitlement import get_entitlement_config_info_async
from ._entitlement import get_platform_entitlement_config
from ._entitlement import get_platform_entitlement_config_async
from ._entitlement import get_user_active_entitlements_by_item_ids
from ._entitlement import get_user_active_entitlements_by_item_ids_async
from ._entitlement import get_user_app_entitlement_by_app_id
from ._entitlement import get_user_app_entitlement_by_app_id_async
from ._entitlement import get_user_app_entitlement_ownership_by_app_id
from ._entitlement import get_user_app_entitlement_ownership_by_app_id_async
from ._entitlement import get_user_entitlement
from ._entitlement import get_user_entitlement_async
from ._entitlement import get_user_entitlement_by_item_id
from ._entitlement import get_user_entitlement_by_item_id_async
from ._entitlement import get_user_entitlement_by_sku
from ._entitlement import get_user_entitlement_by_sku_async
from ._entitlement import get_user_entitlement_histories
from ._entitlement import get_user_entitlement_histories_async
from ._entitlement import get_user_entitlement_ownership_by_item_id
from ._entitlement import get_user_entitlement_ownership_by_item_id_async
from ._entitlement import get_user_entitlement_ownership_by_item_ids
from ._entitlement import get_user_entitlement_ownership_by_item_ids_async
from ._entitlement import get_user_entitlement_ownership_by_sku
from ._entitlement import get_user_entitlement_ownership_by_sku_async
from ._entitlement import grant_entitlements
from ._entitlement import grant_entitlements_async
from ._entitlement import grant_user_entitlement
from ._entitlement import grant_user_entitlement_async
from ._entitlement import pre_check_revoke_user_entitlement_by_use_count
from ._entitlement import pre_check_revoke_user_entitlement_by_use_count_async
from ._entitlement import public_consume_user_entitlement
from ._entitlement import public_consume_user_entitlement_async
from ._entitlement import public_exists_any_my_active_entitlement
from ._entitlement import public_exists_any_my_active_entitlement_async
from ._entitlement import public_exists_any_user_active_entitlement
from ._entitlement import public_exists_any_user_active_entitlement_async
from ._entitlement import public_get_entitlement_ownership_token
from ._entitlement import public_get_entitlement_ownership_token_async
from ._entitlement import public_get_my_app_entitlement_ownership_by_app_id
from ._entitlement import public_get_my_app_entitlement_ownership_by_app_id_async
from ._entitlement import public_get_my_entitlement_ownership_by_item_id
from ._entitlement import public_get_my_entitlement_ownership_by_item_id_async
from ._entitlement import public_get_my_entitlement_ownership_by_sku
from ._entitlement import public_get_my_entitlement_ownership_by_sku_async
from ._entitlement import public_get_user_app_entitlement_by_app_id
from ._entitlement import public_get_user_app_entitlement_by_app_id_async
from ._entitlement import public_get_user_app_entitlement_ownership_by_app_id
from ._entitlement import public_get_user_app_entitlement_ownership_by_app_id_async
from ._entitlement import public_get_user_entitlement
from ._entitlement import public_get_user_entitlement_async
from ._entitlement import public_get_user_entitlement_by_item_id
from ._entitlement import public_get_user_entitlement_by_item_id_async
from ._entitlement import public_get_user_entitlement_by_sku
from ._entitlement import public_get_user_entitlement_by_sku_async
from ._entitlement import public_get_user_entitlement_ownership_by_item_id
from ._entitlement import public_get_user_entitlement_ownership_by_item_id_async
from ._entitlement import public_get_user_entitlement_ownership_by_item_ids
from ._entitlement import public_get_user_entitlement_ownership_by_item_ids_async
from ._entitlement import public_get_user_entitlement_ownership_by_sku
from ._entitlement import public_get_user_entitlement_ownership_by_sku_async
from ._entitlement import public_get_user_entitlements_by_ids
from ._entitlement import public_get_user_entitlements_by_ids_async
from ._entitlement import public_query_user_entitlements
from ._entitlement import public_query_user_entitlements_async
from ._entitlement import public_query_user_entitlements_by_app_type
from ._entitlement import public_query_user_entitlements_by_app_type_async
from ._entitlement import public_sell_user_entitlement
from ._entitlement import public_sell_user_entitlement_async
from ._entitlement import public_split_user_entitlement
from ._entitlement import public_split_user_entitlement_async
from ._entitlement import public_transfer_user_entitlement
from ._entitlement import public_transfer_user_entitlement_async
from ._entitlement import public_user_entitlement_history
from ._entitlement import public_user_entitlement_history_async
from ._entitlement import query_entitlements
from ._entitlement import query_entitlements_async
from ._entitlement import query_entitlements_1
from ._entitlement import query_entitlements_1_async
from ._entitlement import query_user_entitlements
from ._entitlement import query_user_entitlements_async
from ._entitlement import query_user_entitlements_by_app_type
from ._entitlement import query_user_entitlements_by_app_type_async
from ._entitlement import revoke_all_entitlements
from ._entitlement import revoke_all_entitlements_async
from ._entitlement import revoke_entitlements
from ._entitlement import revoke_entitlements_async
from ._entitlement import revoke_use_count
from ._entitlement import revoke_use_count_async
from ._entitlement import revoke_user_entitlement
from ._entitlement import revoke_user_entitlement_async
from ._entitlement import revoke_user_entitlement_by_use_count
from ._entitlement import revoke_user_entitlement_by_use_count_async
from ._entitlement import revoke_user_entitlements
from ._entitlement import revoke_user_entitlements_async
from ._entitlement import sell_user_entitlement
from ._entitlement import sell_user_entitlement_async
from ._entitlement import update_platform_entitlement_config
from ._entitlement import update_platform_entitlement_config_async
from ._entitlement import update_user_entitlement
from ._entitlement import update_user_entitlement_async

from ._fulfillment import fulfill_item
from ._fulfillment import fulfill_item_async
from ._fulfillment import fulfill_items
from ._fulfillment import fulfill_items_async
from ._fulfillment import fulfill_rewards
from ._fulfillment import fulfill_rewards_async
from ._fulfillment import fulfill_rewards_v2
from ._fulfillment import fulfill_rewards_v2_async
from ._fulfillment import pre_check_fulfill_item
from ._fulfillment import pre_check_fulfill_item_async
from ._fulfillment import public_redeem_code
from ._fulfillment import public_redeem_code_async
from ._fulfillment import query_fulfillment_histories
from ._fulfillment import query_fulfillment_histories_async
from ._fulfillment import query_fulfillments
from ._fulfillment import query_fulfillments_async
from ._fulfillment import redeem_code
from ._fulfillment import redeem_code_async
from ._fulfillment import revoke_items
from ._fulfillment import revoke_items_async

from ._fulfillment_script import create_fulfillment_script
from ._fulfillment_script import create_fulfillment_script_async
from ._fulfillment_script import delete_fulfillment_script
from ._fulfillment_script import delete_fulfillment_script_async
from ._fulfillment_script import get_fulfillment_script
from ._fulfillment_script import get_fulfillment_script_async
from ._fulfillment_script import list_fulfillment_scripts
from ._fulfillment_script import list_fulfillment_scripts_async
from ._fulfillment_script import update_fulfillment_script
from ._fulfillment_script import update_fulfillment_script_async

from ._iap import delete_apple_iap_config
from ._iap import delete_apple_iap_config_async
from ._iap import delete_epic_games_iap_config
from ._iap import delete_epic_games_iap_config_async
from ._iap import delete_google_iap_config
from ._iap import delete_google_iap_config_async
from ._iap import delete_iap_item_config
from ._iap import delete_iap_item_config_async
from ._iap import delete_oculus_iap_config
from ._iap import delete_oculus_iap_config_async
from ._iap import delete_playstation_iap_config
from ._iap import delete_playstation_iap_config_async
from ._iap import delete_steam_iap_config
from ._iap import delete_steam_iap_config_async
from ._iap import delete_twitch_iap_config
from ._iap import delete_twitch_iap_config_async
from ._iap import delete_xbl_ap_config
from ._iap import delete_xbl_ap_config_async
from ._iap import get_apple_iap_config
from ._iap import get_apple_iap_config_async
from ._iap import get_epic_games_iap_config
from ._iap import get_epic_games_iap_config_async
from ._iap import get_google_iap_config
from ._iap import get_google_iap_config_async
from ._iap import get_iap_item_config
from ._iap import get_iap_item_config_async
from ._iap import get_iap_item_mapping
from ._iap import get_iap_item_mapping_async
from ._iap import get_oculus_iap_config
from ._iap import get_oculus_iap_config_async
from ._iap import get_play_station_iap_config
from ._iap import get_play_station_iap_config_async
from ._iap import get_steam_iap_config
from ._iap import get_steam_iap_config_async
from ._iap import get_twitch_iap_config
from ._iap import get_twitch_iap_config_async
from ._iap import get_xbl_iap_config
from ._iap import get_xbl_iap_config_async
from ._iap import mock_fulfill_iap_item
from ._iap import mock_fulfill_iap_item_async
from ._iap import public_fulfill_apple_iap_item
from ._iap import public_fulfill_apple_iap_item_async
from ._iap import public_fulfill_google_iap_item
from ._iap import public_fulfill_google_iap_item_async
from ._iap import public_reconcile_play_station_store
from ._iap import public_reconcile_play_station_store_async
from ._iap import public_reconcile_play_station_store_with_multiple_service_labels
from ._iap import public_reconcile_play_station_store_with_multiple_service_labels_async
from ._iap import query_all_user_iap_orders
from ._iap import query_all_user_iap_orders_async
from ._iap import query_user_iap_consume_history
from ._iap import query_user_iap_consume_history_async
from ._iap import query_user_iap_orders
from ._iap import query_user_iap_orders_async
from ._iap import sync_epic_games_inventory
from ._iap import sync_epic_games_inventory_async
from ._iap import sync_oculus_consumable_entitlements
from ._iap import sync_oculus_consumable_entitlements_async
from ._iap import sync_steam_inventory
from ._iap import sync_steam_inventory_async
from ._iap import sync_twitch_drops_entitlement
from ._iap import sync_twitch_drops_entitlement_async
from ._iap import sync_twitch_drops_entitlement_1
from ._iap import sync_twitch_drops_entitlement_1_async
from ._iap import sync_xbox_inventory
from ._iap import sync_xbox_inventory_async
from ._iap import update_apple_iap_config
from ._iap import update_apple_iap_config_async
from ._iap import update_epic_games_iap_config
from ._iap import update_epic_games_iap_config_async
from ._iap import update_google_iap_config
from ._iap import update_google_iap_config_async
from ._iap import update_google_p12_file
from ._iap import update_google_p12_file_async
from ._iap import update_iap_item_config
from ._iap import update_iap_item_config_async
from ._iap import update_oculus_iap_config
from ._iap import update_oculus_iap_config_async
from ._iap import update_playstation_iap_config
from ._iap import update_playstation_iap_config_async
from ._iap import update_steam_iap_config
from ._iap import update_steam_iap_config_async
from ._iap import update_twitch_iap_config
from ._iap import update_twitch_iap_config_async
from ._iap import update_xbl_bp_cert_file
from ._iap import update_xbl_bp_cert_file_async
from ._iap import update_xbl_iap_config
from ._iap import update_xbl_iap_config_async
from ._iap import validate_existed_playstation_iap_config
from ._iap import validate_existed_playstation_iap_config_async
from ._iap import validate_playstation_iap_config
from ._iap import validate_playstation_iap_config_async

from ._invoice import download_invoice_details
from ._invoice import download_invoice_details_async
from ._invoice import generate_invoice_summary
from ._invoice import generate_invoice_summary_async

from ._item import acquire_item
from ._item import acquire_item_async
from ._item import bulk_get_locale_items
from ._item import bulk_get_locale_items_async
from ._item import bulk_update_region_data
from ._item import bulk_update_region_data_async
from ._item import create_item
from ._item import create_item_async
from ._item import create_item_type_config
from ._item import create_item_type_config_async
from ._item import defeature_item
from ._item import defeature_item_async
from ._item import delete_item
from ._item import delete_item_async
from ._item import delete_item_type_config
from ._item import delete_item_type_config_async
from ._item import disable_item
from ._item import disable_item_async
from ._item import enable_item
from ._item import enable_item_async
from ._item import feature_item
from ._item import feature_item_async
from ._item import get_app
from ._item import get_app_async
from ._item import get_available_predicate_types
from ._item import get_available_predicate_types_async
from ._item import get_bulk_item_id_by_skus
from ._item import get_bulk_item_id_by_skus_async
from ._item import get_estimated_price
from ._item import get_estimated_price_async
from ._item import get_item
from ._item import get_item_async
from ._item import get_item_by_app_id
from ._item import get_item_by_app_id_async
from ._item import get_item_by_sku
from ._item import get_item_by_sku_async
from ._item import get_item_dynamic_data
from ._item import get_item_dynamic_data_async
from ._item import get_item_id_by_sku
from ._item import get_item_id_by_sku_async
from ._item import get_item_type_config
from ._item import get_item_type_config_async
from ._item import get_items
from ._item import get_items_async
from ._item import get_locale_item
from ._item import get_locale_item_async
from ._item import get_locale_item_by_sku
from ._item import get_locale_item_by_sku_async
from ._item import list_basic_items_by_features
from ._item import list_basic_items_by_features_async
from ._item import list_item_type_configs
from ._item import list_item_type_configs_async
from ._item import public_bulk_get_items
from ._item import public_bulk_get_items_async
from ._item import public_get_app
from ._item import public_get_app_async
from ._item import public_get_estimated_price
from ._item import public_get_estimated_price_async
from ._item import public_get_item
from ._item import public_get_item_async
from ._item import public_get_item_by_app_id
from ._item import public_get_item_by_app_id_async
from ._item import public_get_item_by_sku
from ._item import public_get_item_by_sku_async
from ._item import public_get_item_dynamic_data
from ._item import public_get_item_dynamic_data_async
from ._item import public_query_items
from ._item import public_query_items_async
from ._item import public_search_items
from ._item import public_search_items_async
from ._item import public_validate_item_purchase_condition
from ._item import public_validate_item_purchase_condition_async
from ._item import query_items
from ._item import query_items_async
from ._item import query_items_v2
from ._item import query_items_v2_async
from ._item import query_uncategorized_items
from ._item import query_uncategorized_items_async
from ._item import return_item
from ._item import return_item_async
from ._item import search_item_type_config
from ._item import search_item_type_config_async
from ._item import search_items
from ._item import search_items_async
from ._item import sync_in_game_item
from ._item import sync_in_game_item_async
from ._item import update_app
from ._item import update_app_async
from ._item import update_item
from ._item import update_item_async
from ._item import update_item_purchase_condition
from ._item import update_item_purchase_condition_async
from ._item import update_item_type_config
from ._item import update_item_type_config_async
from ._item import validate_item_purchase_condition
from ._item import validate_item_purchase_condition_async

from ._key_group import create_key_group
from ._key_group import create_key_group_async
from ._key_group import get_key_group
from ._key_group import get_key_group_async
from ._key_group import get_key_group_by_booth_name
from ._key_group import get_key_group_by_booth_name_async
from ._key_group import get_key_group_dynamic
from ._key_group import get_key_group_dynamic_async
from ._key_group import list_keys
from ._key_group import list_keys_async
from ._key_group import query_key_groups
from ._key_group import query_key_groups_async
from ._key_group import update_key_group
from ._key_group import update_key_group_async
from ._key_group import upload_keys
from ._key_group import upload_keys_async

from ._order import admin_create_user_order
from ._order import admin_create_user_order_async
from ._order import count_of_purchased_item
from ._order import count_of_purchased_item_async
from ._order import download_user_order_receipt
from ._order import download_user_order_receipt_async
from ._order import fulfill_user_order
from ._order import fulfill_user_order_async
from ._order import get_order
from ._order import get_order_async
from ._order import get_order_statistics
from ._order import get_order_statistics_async
from ._order import get_user_order
from ._order import get_user_order_async
from ._order import get_user_order_grant
from ._order import get_user_order_grant_async
from ._order import get_user_order_histories
from ._order import get_user_order_histories_async
from ._order import process_user_order_notification
from ._order import process_user_order_notification_async
from ._order import public_cancel_user_order
from ._order import public_cancel_user_order_async
from ._order import public_create_user_order
from ._order import public_create_user_order_async
from ._order import public_download_user_order_receipt
from ._order import public_download_user_order_receipt_async
from ._order import public_get_user_order
from ._order import public_get_user_order_async
from ._order import public_get_user_order_histories
from ._order import public_get_user_order_histories_async
from ._order import public_preview_order_price
from ._order import public_preview_order_price_async
from ._order import public_query_user_orders
from ._order import public_query_user_orders_async
from ._order import query_orders
from ._order import query_orders_async
from ._order import query_user_orders
from ._order import query_user_orders_async
from ._order import refund_order
from ._order import refund_order_async
from ._order import update_user_order_status
from ._order import update_user_order_status_async

from ._order_dedicated import sync_orders
from ._order_dedicated import sync_orders_async

from ._payment import charge_payment_order
from ._payment import charge_payment_order_async
from ._payment import create_user_payment_order
from ._payment import create_user_payment_order_async
from ._payment import get_payment_order
from ._payment import get_payment_order_async
from ._payment import get_payment_order_charge_status
from ._payment import get_payment_order_charge_status_async
from ._payment import list_ext_order_no_by_ext_tx_id
from ._payment import list_ext_order_no_by_ext_tx_id_async
from ._payment import query_payment_notifications
from ._payment import query_payment_notifications_async
from ._payment import query_payment_orders
from ._payment import query_payment_orders_async
from ._payment import refund_user_payment_order
from ._payment import refund_user_payment_order_async
from ._payment import simulate_payment_order_notification
from ._payment import simulate_payment_order_notification_async

from ._payment_account import public_delete_payment_account
from ._payment_account import public_delete_payment_account_async
from ._payment_account import public_get_payment_accounts
from ._payment_account import public_get_payment_accounts_async

from ._payment_callback_config import get_payment_callback_config
from ._payment_callback_config import get_payment_callback_config_async
from ._payment_callback_config import update_payment_callback_config
from ._payment_callback_config import update_payment_callback_config_async

from ._payment_config import create_payment_provider_config
from ._payment_config import create_payment_provider_config_async
from ._payment_config import debug_matched_payment_merchant_config
from ._payment_config import debug_matched_payment_merchant_config_async
from ._payment_config import debug_matched_payment_provider_config
from ._payment_config import debug_matched_payment_provider_config_async
from ._payment_config import delete_payment_provider_config
from ._payment_config import delete_payment_provider_config_async
from ._payment_config import get_aggregate_payment_providers
from ._payment_config import get_aggregate_payment_providers_async
from ._payment_config import get_payment_merchant_config
from ._payment_config import get_payment_merchant_config_async
from ._payment_config import get_payment_merchant_config_1
from ._payment_config import get_payment_merchant_config_1_async
from ._payment_config import get_payment_tax_config
from ._payment_config import get_payment_tax_config_async
from ._payment_config import get_special_payment_providers
from ._payment_config import get_special_payment_providers_async
from ._payment_config import query_payment_provider_config
from ._payment_config import query_payment_provider_config_async
from ._payment_config import test_adyen_config
from ._payment_config import test_adyen_config_async
from ._payment_config import test_adyen_config_by_id
from ._payment_config import test_adyen_config_by_id_async
from ._payment_config import test_ali_pay_config
from ._payment_config import test_ali_pay_config_async
from ._payment_config import test_ali_pay_config_by_id
from ._payment_config import test_ali_pay_config_by_id_async
from ._payment_config import test_checkout_config
from ._payment_config import test_checkout_config_async
from ._payment_config import test_checkout_config_by_id
from ._payment_config import test_checkout_config_by_id_async
from ._payment_config import test_neon_pay_config
from ._payment_config import test_neon_pay_config_async
from ._payment_config import test_neon_pay_config_by_id
from ._payment_config import test_neon_pay_config_by_id_async
from ._payment_config import test_pay_pal_config
from ._payment_config import test_pay_pal_config_async
from ._payment_config import test_pay_pal_config_by_id
from ._payment_config import test_pay_pal_config_by_id_async
from ._payment_config import test_stripe_config
from ._payment_config import test_stripe_config_async
from ._payment_config import test_stripe_config_by_id
from ._payment_config import test_stripe_config_by_id_async
from ._payment_config import test_wx_pay_config
from ._payment_config import test_wx_pay_config_async
from ._payment_config import test_wx_pay_config_by_id
from ._payment_config import test_wx_pay_config_by_id_async
from ._payment_config import test_xsolla_config
from ._payment_config import test_xsolla_config_async
from ._payment_config import test_xsolla_config_by_id
from ._payment_config import test_xsolla_config_by_id_async
from ._payment_config import update_adyen_config
from ._payment_config import update_adyen_config_async
from ._payment_config import update_ali_pay_config
from ._payment_config import update_ali_pay_config_async
from ._payment_config import update_checkout_config
from ._payment_config import update_checkout_config_async
from ._payment_config import update_neon_pay_config
from ._payment_config import update_neon_pay_config_async
from ._payment_config import update_pay_pal_config
from ._payment_config import update_pay_pal_config_async
from ._payment_config import update_payment_domain_whitelist_config
from ._payment_config import update_payment_domain_whitelist_config_async
from ._payment_config import update_payment_provider_config
from ._payment_config import update_payment_provider_config_async
from ._payment_config import update_payment_tax_config
from ._payment_config import update_payment_tax_config_async
from ._payment_config import update_stripe_config
from ._payment_config import update_stripe_config_async
from ._payment_config import update_wx_pay_config
from ._payment_config import update_wx_pay_config_async
from ._payment_config import update_wx_pay_config_cert
from ._payment_config import update_wx_pay_config_cert_async
from ._payment_config import update_xsolla_config
from ._payment_config import update_xsolla_config_async
from ._payment_config import update_xsolla_ui_config
from ._payment_config import update_xsolla_ui_config_async

from ._payment_dedicated import create_payment_order_by_dedicated
from ._payment_dedicated import create_payment_order_by_dedicated_async
from ._payment_dedicated import refund_payment_order_by_dedicated
from ._payment_dedicated import refund_payment_order_by_dedicated_async
from ._payment_dedicated import sync_payment_orders
from ._payment_dedicated import sync_payment_orders_async

from ._payment_station import get_payment_customization
from ._payment_station import get_payment_customization_async
from ._payment_station import get_payment_public_config
from ._payment_station import get_payment_public_config_async
from ._payment_station import get_payment_tax_value
from ._payment_station import get_payment_tax_value_async
from ._payment_station import pay
from ._payment_station import pay_async
from ._payment_station import public_check_payment_order_paid_status
from ._payment_station import public_check_payment_order_paid_status_async
from ._payment_station import public_get_payment_methods
from ._payment_station import public_get_payment_methods_async
from ._payment_station import public_get_payment_url
from ._payment_station import public_get_payment_url_async
from ._payment_station import public_get_qr_code
from ._payment_station import public_get_qr_code_async
from ._payment_station import public_get_unpaid_payment_order
from ._payment_station import public_get_unpaid_payment_order_async
from ._payment_station import public_normalize_payment_return_url
from ._payment_station import public_normalize_payment_return_url_async

from ._platform import get_psn_entitlement_ownership
from ._platform import get_psn_entitlement_ownership_async
from ._platform import get_xbox_entitlement_ownership
from ._platform import get_xbox_entitlement_ownership_async

from ._platform_account_closure import get_user_platform_account_closure_histories
from ._platform_account_closure import get_user_platform_account_closure_histories_async

from ._revocation import delete_revocation_config
from ._revocation import delete_revocation_config_async
from ._revocation import do_revocation
from ._revocation import do_revocation_async
from ._revocation import get_revocation_config
from ._revocation import get_revocation_config_async
from ._revocation import query_revocation_histories
from ._revocation import query_revocation_histories_async
from ._revocation import update_revocation_config
from ._revocation import update_revocation_config_async

from ._reward import check_event_condition
from ._reward import check_event_condition_async
from ._reward import create_reward
from ._reward import create_reward_async
from ._reward import delete_reward
from ._reward import delete_reward_async
from ._reward import delete_reward_condition_record
from ._reward import delete_reward_condition_record_async
from ._reward import export_rewards
from ._reward import export_rewards_async
from ._reward import get_reward
from ._reward import get_reward_async
from ._reward import get_reward_1
from ._reward import get_reward_1_async
from ._reward import get_reward_by_code
from ._reward import get_reward_by_code_async
from ._reward import import_rewards
from ._reward import import_rewards_async
from ._reward import query_rewards
from ._reward import query_rewards_async
from ._reward import query_rewards_1
from ._reward import query_rewards_1_async
from ._reward import update_reward
from ._reward import update_reward_async

from ._section import create_section
from ._section import create_section_async
from ._section import delete_section
from ._section import delete_section_async
from ._section import get_section
from ._section import get_section_async
from ._section import public_list_active_sections
from ._section import public_list_active_sections_async
from ._section import purge_expired_section
from ._section import purge_expired_section_async
from ._section import query_sections
from ._section import query_sections_async
from ._section import update_section
from ._section import update_section_async

from ._service_plugin_config import delete_loot_box_plugin_config
from ._service_plugin_config import delete_loot_box_plugin_config_async
from ._service_plugin_config import delete_revocation_plugin_config
from ._service_plugin_config import delete_revocation_plugin_config_async
from ._service_plugin_config import delete_section_plugin_config
from ._service_plugin_config import delete_section_plugin_config_async
from ._service_plugin_config import delete_service_plugin_config
from ._service_plugin_config import delete_service_plugin_config_async
from ._service_plugin_config import get_loot_box_grpc_info
from ._service_plugin_config import get_loot_box_grpc_info_async
from ._service_plugin_config import get_loot_box_plugin_config
from ._service_plugin_config import get_loot_box_plugin_config_async
from ._service_plugin_config import get_revocation_plugin_config
from ._service_plugin_config import get_revocation_plugin_config_async
from ._service_plugin_config import get_section_plugin_config
from ._service_plugin_config import get_section_plugin_config_async
from ._service_plugin_config import get_service_plugin_config
from ._service_plugin_config import get_service_plugin_config_async
from ._service_plugin_config import update_loot_box_plugin_config
from ._service_plugin_config import update_loot_box_plugin_config_async
from ._service_plugin_config import update_revocation_plugin_config
from ._service_plugin_config import update_revocation_plugin_config_async
from ._service_plugin_config import update_section_plugin_config
from ._service_plugin_config import update_section_plugin_config_async
from ._service_plugin_config import update_service_plugin_config
from ._service_plugin_config import update_service_plugin_config_async
from ._service_plugin_config import upload_revocation_plugin_config_cert
from ._service_plugin_config import upload_revocation_plugin_config_cert_async
from ._service_plugin_config import upload_section_plugin_config_cert
from ._service_plugin_config import upload_section_plugin_config_cert_async
from ._service_plugin_config import uplod_loot_box_plugin_config_cert
from ._service_plugin_config import uplod_loot_box_plugin_config_cert_async

from ._session_platform import register_xbl_sessions
from ._session_platform import register_xbl_sessions_async

from ._store import clone_store
from ._store import clone_store_async
from ._store import create_store
from ._store import create_store_async
from ._store import delete_published_store
from ._store import delete_published_store_async
from ._store import delete_store
from ._store import delete_store_async
from ._store import download_csv_templates
from ._store import download_csv_templates_async
from ._store import export_store
from ._store import export_store_async
from ._store import export_store_1
from ._store import export_store_1_async
from ._store import export_store_by_csv
from ._store import export_store_by_csv_async
from ._store import get_catalog_config
from ._store import get_catalog_config_async
from ._store import get_catalog_definition
from ._store import get_catalog_definition_async
from ._store import get_published_store
from ._store import get_published_store_async
from ._store import get_published_store_backup
from ._store import get_published_store_backup_async
from ._store import get_store
from ._store import get_store_async
from ._store import import_store
from ._store import import_store_async
from ._store import import_store_1
from ._store import import_store_1_async
from ._store import import_store_by_csv
from ._store import import_store_by_csv_async
from ._store import list_stores
from ._store import list_stores_async
from ._store import public_list_stores
from ._store import public_list_stores_async
from ._store import query_import_history
from ._store import query_import_history_async
from ._store import rollback_published_store
from ._store import rollback_published_store_async
from ._store import update_catalog_config
from ._store import update_catalog_config_async
from ._store import update_store
from ._store import update_store_async

from ._subscription import cancel_subscription
from ._subscription import cancel_subscription_async
from ._subscription import check_user_subscription_subscribable_by_item_id
from ._subscription import check_user_subscription_subscribable_by_item_id_async
from ._subscription import delete_user_subscription
from ._subscription import delete_user_subscription_async
from ._subscription import get_user_subscription
from ._subscription import get_user_subscription_async
from ._subscription import get_user_subscription_activities
from ._subscription import get_user_subscription_activities_async
from ._subscription import get_user_subscription_billing_histories
from ._subscription import get_user_subscription_billing_histories_async
from ._subscription import grant_days_to_subscription
from ._subscription import grant_days_to_subscription_async
from ._subscription import platform_subscribe_subscription
from ._subscription import platform_subscribe_subscription_async
from ._subscription import process_user_subscription_notification
from ._subscription import process_user_subscription_notification_async
from ._subscription import public_cancel_subscription
from ._subscription import public_cancel_subscription_async
from ._subscription import public_change_subscription_billing_account
from ._subscription import public_change_subscription_billing_account_async
from ._subscription import public_check_user_subscription_subscribable_by_item_id
from ._subscription import public_check_user_subscription_subscribable_by_item_id_async
from ._subscription import public_get_user_subscription
from ._subscription import public_get_user_subscription_async
from ._subscription import public_get_user_subscription_billing_histories
from ._subscription import public_get_user_subscription_billing_histories_async
from ._subscription import public_query_user_subscriptions
from ._subscription import public_query_user_subscriptions_async
from ._subscription import public_subscribe_subscription
from ._subscription import public_subscribe_subscription_async
from ._subscription import query_subscriptions
from ._subscription import query_subscriptions_async
from ._subscription import query_user_subscriptions
from ._subscription import query_user_subscriptions_async
from ._subscription import recurring_charge_subscription
from ._subscription import recurring_charge_subscription_async

from ._ticket import acquire_user_ticket
from ._ticket import acquire_user_ticket_async
from ._ticket import decrease_ticket_sale
from ._ticket import decrease_ticket_sale_async
from ._ticket import get_ticket_booth_id
from ._ticket import get_ticket_booth_id_async
from ._ticket import get_ticket_dynamic
from ._ticket import get_ticket_dynamic_async
from ._ticket import increase_ticket_sale
from ._ticket import increase_ticket_sale_async

from ._trade_action import commit
from ._trade_action import commit_async
from ._trade_action import get_trade_history_by_criteria
from ._trade_action import get_trade_history_by_criteria_async
from ._trade_action import get_trade_history_by_transaction_id
from ._trade_action import get_trade_history_by_transaction_id_async

from ._view import create_view
from ._view import create_view_async
from ._view import delete_view
from ._view import delete_view_async
from ._view import get_view
from ._view import get_view_async
from ._view import list_views
from ._view import list_views_async
from ._view import public_list_views
from ._view import public_list_views_async
from ._view import update_view
from ._view import update_view_async

from ._wallet import bulk_credit
from ._wallet import bulk_credit_async
from ._wallet import bulk_debit
from ._wallet import bulk_debit_async
from ._wallet import check_balance
from ._wallet import check_balance_async
from ._wallet import check_wallet
from ._wallet import check_wallet_async
from ._wallet import credit_user_wallet
from ._wallet import credit_user_wallet_async
from ._wallet import debit_by_wallet_platform
from ._wallet import debit_by_wallet_platform_async
from ._wallet import debit_user_wallet
from ._wallet import debit_user_wallet_async
from ._wallet import debit_user_wallet_by_currency_code
from ._wallet import debit_user_wallet_by_currency_code_async
from ._wallet import disable_user_wallet
from ._wallet import disable_user_wallet_async
from ._wallet import enable_user_wallet
from ._wallet import enable_user_wallet_async
from ._wallet import get_platform_wallet_config
from ._wallet import get_platform_wallet_config_async
from ._wallet import get_user_wallet
from ._wallet import get_user_wallet_async
from ._wallet import get_wallet
from ._wallet import get_wallet_async
from ._wallet import list_user_currency_transactions
from ._wallet import list_user_currency_transactions_async
from ._wallet import list_user_wallet_transactions
from ._wallet import list_user_wallet_transactions_async
from ._wallet import pay_with_user_wallet
from ._wallet import pay_with_user_wallet_async
from ._wallet import public_get_my_wallet
from ._wallet import public_get_my_wallet_async
from ._wallet import public_get_wallet
from ._wallet import public_get_wallet_async
from ._wallet import public_list_user_wallet_transactions
from ._wallet import public_list_user_wallet_transactions_async
from ._wallet import query_user_currency_wallets
from ._wallet import query_user_currency_wallets_async
from ._wallet import query_wallets
from ._wallet import query_wallets_async
from ._wallet import reset_platform_wallet_config
from ._wallet import reset_platform_wallet_config_async
from ._wallet import update_platform_wallet_config
from ._wallet import update_platform_wallet_config_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Matchmaking Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ServiceGetSessionHistorySearchResponseItemV2(Model):
    """Service get session history search response item V2 (service.GetSessionHistorySearchResponseItemV2)

    Properties:
        created_at: (created_at) REQUIRED str

        game_mode: (game_mode) REQUIRED str

        id_: (_id) REQUIRED str

        joinable: (joinable) REQUIRED bool

        match_id: (match_id) REQUIRED str

        namespace: (namespace) REQUIRED str

        status: (status) REQUIRED str

        sub_game_mode: (sub_game_mode) REQUIRED List[str]
    """

    # region fields

    created_at: str  # REQUIRED
    game_mode: str  # REQUIRED
    id_: str  # REQUIRED
    joinable: bool  # REQUIRED
    match_id: str  # REQUIRED
    namespace: str  # REQUIRED
    status: str  # REQUIRED
    sub_game_mode: List[str]  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_created_at(
        self, value: str
    ) -> ServiceGetSessionHistorySearchResponseItemV2:
        self.created_at = value
        return self

    def with_game_mode(
        self, value: str
    ) -> ServiceGetSessionHistorySearchResponseItemV2:
        self.game_mode = value
        return self

    def with_id(self, value: str) -> ServiceGetSessionHistorySearchResponseItemV2:
        self.id_ = value
        return self

    def with_joinable(
        self, value: bool
    ) -> ServiceGetSessionHistorySearchResponseItemV2:
        self.joinable = value
        return self

    def with_match_id(self, value: str) -> ServiceGetSessionHistorySearchResponseItemV2:
        self.match_id = value
        return self

    def with_namespace(
        self, value: str
    ) -> ServiceGetSessionHistorySearchResponseItemV2:
        self.namespace = value
        return self

    def with_status(self, value: str) -> ServiceGetSessionHistorySearchResponseItemV2:
        self.status = value
        return self

    def with_sub_game_mode(
        self, value: List[str]
    ) -> ServiceGetSessionHistorySearchResponseItemV2:
        self.sub_game_mode = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["created_at"] = str(self.created_at)
        elif include_empty:
            result["created_at"] = ""
        if hasattr(self, "game_mode"):
            result["game_mode"] = str(self.game_mode)
        elif include_empty:
            result["game_mode"] = ""
        if hasattr(self, "id_"):
            result["_id"] = str(self.id_)
        elif include_empty:
            result["_id"] = ""
        if hasattr(self, "joinable"):
            result["joinable"] = bool(self.joinable)
        elif include_empty:
            result["joinable"] = False
        if hasattr(self, "match_id"):
            result["match_id"] = str(self.match_id)
        elif include_empty:
            result["match_id"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        if hasattr(self, "sub_game_mode"):
            result["sub_game_mode"] = [str(i0) for i0 in self.sub_game_mode]
        elif include_empty:
            result["sub_game_mode"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: str,
        game_mode: str,
        id_: str,
        joinable: bool,
        match_id: str,
        namespace: str,
        status: str,
        sub_game_mode: List[str],
        **kwargs,
    ) -> ServiceGetSessionHistorySearchResponseItemV2:
        instance = cls()
        instance.created_at = created_at
        instance.game_mode = game_mode
        instance.id_ = id_
        instance.joinable = joinable
        instance.match_id = match_id
        instance.namespace = namespace
        instance.status = status
        instance.sub_game_mode = sub_game_mode
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ServiceGetSessionHistorySearchResponseItemV2:
        instance = cls()
        if not dict_:
            return instance
        if "created_at" in dict_ and dict_["created_at"] is not None:
            instance.created_at = str(dict_["created_at"])
        elif include_empty:
            instance.created_at = ""
        if "game_mode" in dict_ and dict_["game_mode"] is not None:
            instance.game_mode = str(dict_["game_mode"])
        elif include_empty:
            instance.game_mode = ""
        if "_id" in dict_ and dict_["_id"] is not None:
            instance.id_ = str(dict_["_id"])
        elif include_empty:
            instance.id_ = ""
        if "joinable" in dict_ and dict_["joinable"] is not None:
            instance.joinable = bool(dict_["joinable"])
        elif include_empty:
            instance.joinable = False
        if "match_id" in dict_ and dict_["match_id"] is not None:
            instance.match_id = str(dict_["match_id"])
        elif include_empty:
            instance.match_id = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        if "sub_game_mode" in dict_ and dict_["sub_game_mode"] is not None:
            instance.sub_game_mode = [str(i0) for i0 in dict_["sub_game_mode"]]
        elif include_empty:
            instance.sub_game_mode = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ServiceGetSessionHistorySearchResponseItemV2]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ServiceGetSessionHistorySearchResponseItemV2]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ServiceGetSessionHistorySearchResponseItemV2,
        List[ServiceGetSessionHistorySearchResponseItemV2],
        Dict[Any, ServiceGetSessionHistorySearchResponseItemV2],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "created_at": "created_at",
            "game_mode": "game_mode",
            "_id": "id_",
            "joinable": "joinable",
            "match_id": "match_id",
            "namespace": "namespace",
            "status": "status",
            "sub_game_mode": "sub_game_mode",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "created_at": True,
            "game_mode": True,
            "_id": True,
            "joinable": True,
            "match_id": True,
            "namespace": True,
            "status": True,
            "sub_game_mode": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Legal Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.localized_policy_version_object import LocalizedPolicyVersionObject


class RetrieveUserAcceptedAgreementResponse(Model):
    """Retrieve user accepted agreement response (RetrieveUserAcceptedAgreementResponse)

    Properties:
        id_: (id) REQUIRED str

        created_at: (createdAt) OPTIONAL str

        display_name: (displayName) OPTIONAL str

        email: (email) OPTIONAL str

        is_accepted: (isAccepted) OPTIONAL bool

        localized_policy_version: (localizedPolicyVersion) OPTIONAL LocalizedPolicyVersionObject

        namespace: (namespace) OPTIONAL str

        policy_name: (policyName) OPTIONAL str

        policy_type: (policyType) OPTIONAL str

        publisher_user_id: (publisherUserId) OPTIONAL str

        signing_date: (signingDate) OPTIONAL str

        updated_at: (updatedAt) OPTIONAL str

        user_id: (userId) OPTIONAL str

        username: (username) OPTIONAL str
    """

    # region fields

    id_: str  # REQUIRED
    created_at: str  # OPTIONAL
    display_name: str  # OPTIONAL
    email: str  # OPTIONAL
    is_accepted: bool  # OPTIONAL
    localized_policy_version: LocalizedPolicyVersionObject  # OPTIONAL
    namespace: str  # OPTIONAL
    policy_name: str  # OPTIONAL
    policy_type: str  # OPTIONAL
    publisher_user_id: str  # OPTIONAL
    signing_date: str  # OPTIONAL
    updated_at: str  # OPTIONAL
    user_id: str  # OPTIONAL
    username: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_id(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.id_ = value
        return self

    def with_created_at(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.created_at = value
        return self

    def with_display_name(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.display_name = value
        return self

    def with_email(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.email = value
        return self

    def with_is_accepted(self, value: bool) -> RetrieveUserAcceptedAgreementResponse:
        self.is_accepted = value
        return self

    def with_localized_policy_version(
        self, value: LocalizedPolicyVersionObject
    ) -> RetrieveUserAcceptedAgreementResponse:
        self.localized_policy_version = value
        return self

    def with_namespace(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.namespace = value
        return self

    def with_policy_name(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.policy_name = value
        return self

    def with_policy_type(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.policy_type = value
        return self

    def with_publisher_user_id(
        self, value: str
    ) -> RetrieveUserAcceptedAgreementResponse:
        self.publisher_user_id = value
        return self

    def with_signing_date(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.signing_date = value
        return self

    def with_updated_at(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.updated_at = value
        return self

    def with_user_id(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.user_id = value
        return self

    def with_username(self, value: str) -> RetrieveUserAcceptedAgreementResponse:
        self.username = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "display_name"):
            result["displayName"] = str(self.display_name)
        elif include_empty:
            result["displayName"] = ""
        if hasattr(self, "email"):
            result["email"] = str(self.email)
        elif include_empty:
            result["email"] = ""
        if hasattr(self, "is_accepted"):
            result["isAccepted"] = bool(self.is_accepted)
        elif include_empty:
            result["isAccepted"] = False
        if hasattr(self, "localized_policy_version"):
            result["localizedPolicyVersion"] = self.localized_policy_version.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["localizedPolicyVersion"] = LocalizedPolicyVersionObject()
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "policy_name"):
            result["policyName"] = str(self.policy_name)
        elif include_empty:
            result["policyName"] = ""
        if hasattr(self, "policy_type"):
            result["policyType"] = str(self.policy_type)
        elif include_empty:
            result["policyType"] = ""
        if hasattr(self, "publisher_user_id"):
            result["publisherUserId"] = str(self.publisher_user_id)
        elif include_empty:
            result["publisherUserId"] = ""
        if hasattr(self, "signing_date"):
            result["signingDate"] = str(self.signing_date)
        elif include_empty:
            result["signingDate"] = ""
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        if hasattr(self, "username"):
            result["username"] = str(self.username)
        elif include_empty:
            result["username"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        id_: str,
        created_at: Optional[str] = None,
        display_name: Optional[str] = None,
        email: Optional[str] = None,
        is_accepted: Optional[bool] = None,
        localized_policy_version: Optional[LocalizedPolicyVersionObject] = None,
        namespace: Optional[str] = None,
        policy_name: Optional[str] = None,
        policy_type: Optional[str] = None,
        publisher_user_id: Optional[str] = None,
        signing_date: Optional[str] = None,
        updated_at: Optional[str] = None,
        user_id: Optional[str] = None,
        username: Optional[str] = None,
        **kwargs,
    ) -> RetrieveUserAcceptedAgreementResponse:
        instance = cls()
        instance.id_ = id_
        if created_at is not None:
            instance.created_at = created_at
        if display_name is not None:
            instance.display_name = display_name
        if email is not None:
            instance.email = email
        if is_accepted is not None:
            instance.is_accepted = is_accepted
        if localized_policy_version is not None:
            instance.localized_policy_version = localized_policy_version
        if namespace is not None:
            instance.namespace = namespace
        if policy_name is not None:
            instance.policy_name = policy_name
        if policy_type is not None:
            instance.policy_type = policy_type
        if publisher_user_id is not None:
            instance.publisher_user_id = publisher_user_id
        if signing_date is not None:
            instance.signing_date = signing_date
        if updated_at is not None:
            instance.updated_at = updated_at
        if user_id is not None:
            instance.user_id = user_id
        if username is not None:
            instance.username = username
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> RetrieveUserAcceptedAgreementResponse:
        instance = cls()
        if not dict_:
            return instance
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "displayName" in dict_ and dict_["displayName"] is not None:
            instance.display_name = str(dict_["displayName"])
        elif include_empty:
            instance.display_name = ""
        if "email" in dict_ and dict_["email"] is not None:
            instance.email = str(dict_["email"])
        elif include_empty:
            instance.email = ""
        if "isAccepted" in dict_ and dict_["isAccepted"] is not None:
            instance.is_accepted = bool(dict_["isAccepted"])
        elif include_empty:
            instance.is_accepted = False
        if (
            "localizedPolicyVersion" in dict_
            and dict_["localizedPolicyVersion"] is not None
        ):
            instance.localized_policy_version = (
                LocalizedPolicyVersionObject.create_from_dict(
                    dict_["localizedPolicyVersion"], include_empty=include_empty
                )
            )
        elif include_empty:
            instance.localized_policy_version = LocalizedPolicyVersionObject()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "policyName" in dict_ and dict_["policyName"] is not None:
            instance.policy_name = str(dict_["policyName"])
        elif include_empty:
            instance.policy_name = ""
        if "policyType" in dict_ and dict_["policyType"] is not None:
            instance.policy_type = str(dict_["policyType"])
        elif include_empty:
            instance.policy_type = ""
        if "publisherUserId" in dict_ and dict_["publisherUserId"] is not None:
            instance.publisher_user_id = str(dict_["publisherUserId"])
        elif include_empty:
            instance.publisher_user_id = ""
        if "signingDate" in dict_ and dict_["signingDate"] is not None:
            instance.signing_date = str(dict_["signingDate"])
        elif include_empty:
            instance.signing_date = ""
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        if "username" in dict_ and dict_["username"] is not None:
            instance.username = str(dict_["username"])
        elif include_empty:
            instance.username = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, RetrieveUserAcceptedAgreementResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[RetrieveUserAcceptedAgreementResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        RetrieveUserAcceptedAgreementResponse,
        List[RetrieveUserAcceptedAgreementResponse],
        Dict[Any, RetrieveUserAcceptedAgreementResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "id": "id_",
            "createdAt": "created_at",
            "displayName": "display_name",
            "email": "email",
            "isAccepted": "is_accepted",
            "localizedPolicyVersion": "localized_policy_version",
            "namespace": "namespace",
            "policyName": "policy_name",
            "policyType": "policy_type",
            "publisherUserId": "publisher_user_id",
            "signingDate": "signing_date",
            "updatedAt": "updated_at",
            "userId": "user_id",
            "username": "username",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "id": True,
            "createdAt": False,
            "displayName": False,
            "email": False,
            "isAccepted": False,
            "localizedPolicyVersion": False,
            "namespace": False,
            "policyName": False,
            "policyType": False,
            "publisherUserId": False,
            "signingDate": False,
            "updatedAt": False,
            "userId": False,
            "username": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "1.44.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .retrieve_country_list_w_8c69ff import RetrieveCountryListWithPolicies
from .retrieve_latest_policies import RetrieveLatestPolicies
from .retrieve_latest_policies import (
    PolicyTypeEnum as RetrieveLatestPoliciesPolicyTypeEnum,
)
from .retrieve_latest_policie_95ffb6 import (
    RetrieveLatestPoliciesByNamespaceAndCountryPublic,
)
from .retrieve_latest_policie_95ffb6 import (
    PolicyTypeEnum as RetrieveLatestPoliciesByNamespaceAndCountryPublicPolicyTypeEnum,
)
from .retrieve_latest_policie_29f65f import RetrieveLatestPoliciesPublic
from .retrieve_latest_policie_29f65f import (
    PolicyTypeEnum as RetrieveLatestPoliciesPublicPolicyTypeEnum,
)
from .retrieve_policies import RetrievePolicies
from .set_default_policy_2 import SetDefaultPolicy2
from .update_policy import UpdatePolicy



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ErrorEntity

from ..operations.export import ExportSeason


@same_doc_as(ExportSeason)
def export_season(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """export season service data (exportSeason)

    This API is used to export all of season service data files with csv format.

    Properties:
        url: /seasonpass/admin/namespace/{namespace}/export

        method: GET

        tags: ["Export"]

        consumes: []

        produces: ["application/octet-stream"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - Any (Export data successfully)

        400: Bad Request - ErrorEntity (49143: Season [{seasonId}] does not exist in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ExportSeason.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ExportSeason)
async def export_season_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """export season service data (exportSeason)

    This API is used to export all of season service data files with csv format.

    Properties:
        url: /seasonpass/admin/namespace/{namespace}/export

        method: GET

        tags: ["Export"]

        consumes: []

        produces: ["application/octet-stream"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - Any (Export data successfully)

        400: Bad Request - ErrorEntity (49143: Season [{seasonId}] does not exist in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ExportSeason.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import RestapiErrorResponse
from ..models import RestapiReportListResponse
from ..models import RestapiTicketListResponse
from ..models import RestapiTicketResponse
from ..models import RestapiTicketStatisticResponse
from ..models import RestapiUpdateTicketResolutionsRequest

from ..operations.admin_tickets import DeleteTicket
from ..operations.admin_tickets import GetReportsByTicket
from ..operations.admin_tickets import GetTicketDetail
from ..operations.admin_tickets import ListTickets
from ..operations.admin_tickets import TicketStatistic
from ..operations.admin_tickets import UpdateTicketResolutions
from ..models import RestapiTicketResponseCategoryEnum, RestapiTicketResponseStatusEnum
from ..models import RestapiUpdateTicketResolutionsRequestStatusEnum


@same_doc_as(DeleteTicket)
def delete_ticket(
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete single ticket (deleteTicket)

    This endpoint will delete ticket and all its reports.

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/{ticketId}

        method: DELETE

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        204: No Content -

        404: Not Found - RestapiErrorResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteTicket.create(
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteTicket)
async def delete_ticket_async(
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete single ticket (deleteTicket)

    This endpoint will delete ticket and all its reports.

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/{ticketId}

        method: DELETE

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        204: No Content -

        404: Not Found - RestapiErrorResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteTicket.create(
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetReportsByTicket)
def get_reports_by_ticket(
    ticket_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get reports by ticket ID (getReportsByTicket)

    List reports ordered by createdAt in descending order.

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/{ticketId}/reports

        method: GET

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - RestapiReportListResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetReportsByTicket.create(
        ticket_id=ticket_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetReportsByTicket)
async def get_reports_by_ticket_async(
    ticket_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get reports by ticket ID (getReportsByTicket)

    List reports ordered by createdAt in descending order.

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/{ticketId}/reports

        method: GET

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - RestapiReportListResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetReportsByTicket.create(
        ticket_id=ticket_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetTicketDetail)
def get_ticket_detail(
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get single ticket (getTicketDetail)

    This endpoint will return ticket detail with ticket id.

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/{ticketId}

        method: GET

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        200: OK - RestapiTicketResponse

        404: Not Found - RestapiErrorResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetTicketDetail.create(
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetTicketDetail)
async def get_ticket_detail_async(
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get single ticket (getTicketDetail)

    This endpoint will return ticket detail with ticket id.

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/{ticketId}

        method: GET

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        200: OK - RestapiTicketResponse

        404: Not Found - RestapiErrorResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetTicketDetail.create(
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ListTickets)
def list_tickets(
    category: Optional[str] = None,
    extension_category: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    reported_user_id: Optional[str] = None,
    sort_by: Optional[str] = None,
    status: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """List report tickets (listTickets)

    Tickets list can be ordered by:
    - createdAt
    - reportsCount
    - status (currently there are OPEN, AUTO_MODERATED and CLOSED statuses, desc order will put ticket with CLOSED status at the top)

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets

        method: GET

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        category: (category) OPTIONAL str in query

        extension_category: (extensionCategory) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        reported_user_id: (reportedUserId) OPTIONAL str in query

        sort_by: (sortBy) OPTIONAL str in query

        status: (status) OPTIONAL str in query

    Responses:
        200: OK - RestapiTicketListResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListTickets.create(
        category=category,
        extension_category=extension_category,
        limit=limit,
        offset=offset,
        order=order,
        reported_user_id=reported_user_id,
        sort_by=sort_by,
        status=status,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ListTickets)
async def list_tickets_async(
    category: Optional[str] = None,
    extension_category: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    reported_user_id: Optional[str] = None,
    sort_by: Optional[str] = None,
    status: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """List report tickets (listTickets)

    Tickets list can be ordered by:
    - createdAt
    - reportsCount
    - status (currently there are OPEN, AUTO_MODERATED and CLOSED statuses, desc order will put ticket with CLOSED status at the top)

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets

        method: GET

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        category: (category) OPTIONAL str in query

        extension_category: (extensionCategory) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        reported_user_id: (reportedUserId) OPTIONAL str in query

        sort_by: (sortBy) OPTIONAL str in query

        status: (status) OPTIONAL str in query

    Responses:
        200: OK - RestapiTicketListResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListTickets.create(
        category=category,
        extension_category=extension_category,
        limit=limit,
        offset=offset,
        order=order,
        reported_user_id=reported_user_id,
        sort_by=sort_by,
        status=status,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TicketStatistic)
def ticket_statistic(
    category: str,
    extension_category: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Ticket statistic (ticketStatistic)

    Ticket statistic can be filtered by:
    - category
    - extension category

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/statistic

        method: GET

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        extension_category: (extensionCategory) OPTIONAL str in query

        category: (category) REQUIRED str in query

    Responses:
        200: OK - RestapiTicketStatisticResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = TicketStatistic.create(
        category=category,
        extension_category=extension_category,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TicketStatistic)
async def ticket_statistic_async(
    category: str,
    extension_category: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Ticket statistic (ticketStatistic)

    Ticket statistic can be filtered by:
    - category
    - extension category

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/statistic

        method: GET

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        extension_category: (extensionCategory) OPTIONAL str in query

        category: (category) REQUIRED str in query

    Responses:
        200: OK - RestapiTicketStatisticResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = TicketStatistic.create(
        category=category,
        extension_category=extension_category,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateTicketResolutions)
def update_ticket_resolutions(
    body: RestapiUpdateTicketResolutionsRequest,
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update ticket resolution to a given status (updateTicketResolutions)

    Update ticket resolution status to either OPEN or CLOSED. It is mandatory to provide notes

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/{ticketId}/resolutions

        method: POST

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED RestapiUpdateTicketResolutionsRequest in body

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        200: OK - RestapiTicketResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateTicketResolutions.create(
        body=body,
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateTicketResolutions)
async def update_ticket_resolutions_async(
    body: RestapiUpdateTicketResolutionsRequest,
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update ticket resolution to a given status (updateTicketResolutions)

    Update ticket resolution status to either OPEN or CLOSED. It is mandatory to provide notes

    Properties:
        url: /reporting/v1/admin/namespaces/{namespace}/tickets/{ticketId}/resolutions

        method: POST

        tags: ["Admin Tickets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED RestapiUpdateTicketResolutionsRequest in body

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        200: OK - RestapiTicketResponse

        500: Internal Server Error - RestapiErrorResponse
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateTicketResolutions.create(
        body=body,
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import LogAppMessageDeclaration
from ..models import ResponseError

from ..operations.operations import PublicGetMessages


@same_doc_as(PublicGetMessages)
def public_get_messages(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """get service messages (publicGetMessages)

    get the list of messages.

    Properties:
        url: /dsartifact/v1/messages

        method: GET

        tags: []

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - List[LogAppMessageDeclaration]

        500: Internal Server Error - ResponseError
    """
    request = PublicGetMessages.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetMessages)
async def public_get_messages_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """get service messages (publicGetMessages)

    get the list of messages.

    Properties:
        url: /dsartifact/v1/messages

        method: GET

        tags: []

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - List[LogAppMessageDeclaration]

        500: Internal Server Error - ResponseError
    """
    request = PublicGetMessages.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Challenge Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.model_user_progression_period_response_meta import (
    ModelUserProgressionPeriodResponseMeta,
)


class ModelUserProgressionResponseMeta(Model):
    """Model user progression response meta (model.UserProgressionResponseMeta)

    Properties:
        code: (code) REQUIRED str

        description: (description) REQUIRED str

        name: (name) REQUIRED str

        period: (period) REQUIRED ModelUserProgressionPeriodResponseMeta

        start_date: (startDate) REQUIRED str

        user_id: (userId) REQUIRED str

        end_date: (endDate) OPTIONAL str
    """

    # region fields

    code: str  # REQUIRED
    description: str  # REQUIRED
    name: str  # REQUIRED
    period: ModelUserProgressionPeriodResponseMeta  # REQUIRED
    start_date: str  # REQUIRED
    user_id: str  # REQUIRED
    end_date: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_code(self, value: str) -> ModelUserProgressionResponseMeta:
        self.code = value
        return self

    def with_description(self, value: str) -> ModelUserProgressionResponseMeta:
        self.description = value
        return self

    def with_name(self, value: str) -> ModelUserProgressionResponseMeta:
        self.name = value
        return self

    def with_period(
        self, value: ModelUserProgressionPeriodResponseMeta
    ) -> ModelUserProgressionResponseMeta:
        self.period = value
        return self

    def with_start_date(self, value: str) -> ModelUserProgressionResponseMeta:
        self.start_date = value
        return self

    def with_user_id(self, value: str) -> ModelUserProgressionResponseMeta:
        self.user_id = value
        return self

    def with_end_date(self, value: str) -> ModelUserProgressionResponseMeta:
        self.end_date = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "code"):
            result["code"] = str(self.code)
        elif include_empty:
            result["code"] = ""
        if hasattr(self, "description"):
            result["description"] = str(self.description)
        elif include_empty:
            result["description"] = ""
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "period"):
            result["period"] = self.period.to_dict(include_empty=include_empty)
        elif include_empty:
            result["period"] = ModelUserProgressionPeriodResponseMeta()
        if hasattr(self, "start_date"):
            result["startDate"] = str(self.start_date)
        elif include_empty:
            result["startDate"] = ""
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        if hasattr(self, "end_date"):
            result["endDate"] = str(self.end_date)
        elif include_empty:
            result["endDate"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        code: str,
        description: str,
        name: str,
        period: ModelUserProgressionPeriodResponseMeta,
        start_date: str,
        user_id: str,
        end_date: Optional[str] = None,
        **kwargs,
    ) -> ModelUserProgressionResponseMeta:
        instance = cls()
        instance.code = code
        instance.description = description
        instance.name = name
        instance.period = period
        instance.start_date = start_date
        instance.user_id = user_id
        if end_date is not None:
            instance.end_date = end_date
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelUserProgressionResponseMeta:
        instance = cls()
        if not dict_:
            return instance
        if "code" in dict_ and dict_["code"] is not None:
            instance.code = str(dict_["code"])
        elif include_empty:
            instance.code = ""
        if "description" in dict_ and dict_["description"] is not None:
            instance.description = str(dict_["description"])
        elif include_empty:
            instance.description = ""
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "period" in dict_ and dict_["period"] is not None:
            instance.period = ModelUserProgressionPeriodResponseMeta.create_from_dict(
                dict_["period"], include_empty=include_empty
            )
        elif include_empty:
            instance.period = ModelUserProgressionPeriodResponseMeta()
        if "startDate" in dict_ and dict_["startDate"] is not None:
            instance.start_date = str(dict_["startDate"])
        elif include_empty:
            instance.start_date = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        if "endDate" in dict_ and dict_["endDate"] is not None:
            instance.end_date = str(dict_["endDate"])
        elif include_empty:
            instance.end_date = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelUserProgressionResponseMeta]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelUserProgressionResponseMeta]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelUserProgressionResponseMeta,
        List[ModelUserProgressionResponseMeta],
        Dict[Any, ModelUserProgressionResponseMeta],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "code": "code",
            "description": "description",
            "name": "name",
            "period": "period",
            "startDate": "start_date",
            "userId": "user_id",
            "endDate": "end_date",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "code": True,
            "description": True,
            "name": True,
            "period": True,
            "startDate": True,
            "userId": True,
            "endDate": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class RedeemableItem(Model):
    """Redeemable item (RedeemableItem)

    Properties:
        item_id: (itemId) REQUIRED str

        item_name: (itemName) REQUIRED str

        extra_subscription_days: (extraSubscriptionDays) OPTIONAL int

        quantity: (quantity) OPTIONAL int
    """

    # region fields

    item_id: str  # REQUIRED
    item_name: str  # REQUIRED
    extra_subscription_days: int  # OPTIONAL
    quantity: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_item_id(self, value: str) -> RedeemableItem:
        self.item_id = value
        return self

    def with_item_name(self, value: str) -> RedeemableItem:
        self.item_name = value
        return self

    def with_extra_subscription_days(self, value: int) -> RedeemableItem:
        self.extra_subscription_days = value
        return self

    def with_quantity(self, value: int) -> RedeemableItem:
        self.quantity = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "item_id"):
            result["itemId"] = str(self.item_id)
        elif include_empty:
            result["itemId"] = ""
        if hasattr(self, "item_name"):
            result["itemName"] = str(self.item_name)
        elif include_empty:
            result["itemName"] = ""
        if hasattr(self, "extra_subscription_days"):
            result["extraSubscriptionDays"] = int(self.extra_subscription_days)
        elif include_empty:
            result["extraSubscriptionDays"] = 0
        if hasattr(self, "quantity"):
            result["quantity"] = int(self.quantity)
        elif include_empty:
            result["quantity"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        item_id: str,
        item_name: str,
        extra_subscription_days: Optional[int] = None,
        quantity: Optional[int] = None,
        **kwargs,
    ) -> RedeemableItem:
        instance = cls()
        instance.item_id = item_id
        instance.item_name = item_name
        if extra_subscription_days is not None:
            instance.extra_subscription_days = extra_subscription_days
        if quantity is not None:
            instance.quantity = quantity
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> RedeemableItem:
        instance = cls()
        if not dict_:
            return instance
        if "itemId" in dict_ and dict_["itemId"] is not None:
            instance.item_id = str(dict_["itemId"])
        elif include_empty:
            instance.item_id = ""
        if "itemName" in dict_ and dict_["itemName"] is not None:
            instance.item_name = str(dict_["itemName"])
        elif include_empty:
            instance.item_name = ""
        if (
            "extraSubscriptionDays" in dict_
            and dict_["extraSubscriptionDays"] is not None
        ):
            instance.extra_subscription_days = int(dict_["extraSubscriptionDays"])
        elif include_empty:
            instance.extra_subscription_days = 0
        if "quantity" in dict_ and dict_["quantity"] is not None:
            instance.quantity = int(dict_["quantity"])
        elif include_empty:
            instance.quantity = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, RedeemableItem]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[RedeemableItem]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[RedeemableItem, List[RedeemableItem], Dict[Any, RedeemableItem]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "itemId": "item_id",
            "itemName": "item_name",
            "extraSubscriptionDays": "extra_subscription_days",
            "quantity": "quantity",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "itemId": True,
            "itemName": True,
            "extraSubscriptionDays": False,
            "quantity": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.21.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_bulk_get_admin_ga_c5c529 import AdminBulkGetAdminGameRecordV1
from .admin_bulk_get_admin_pl_b8e62a import AdminBulkGetAdminPlayerRecordV1
from .admin_delete_admin_game_1f080f import AdminDeleteAdminGameRecordV1
from .admin_delete_admin_play_632fe7 import AdminDeleteAdminPlayerRecordV1
from .admin_get_admin_game_record_v1 import AdminGetAdminGameRecordV1
from .admin_get_admin_player__37ad38 import AdminGetAdminPlayerRecordV1
from .admin_list_admin_game_r_476bfb import AdminListAdminGameRecordV1
from .admin_list_admin_user_r_83dd7a import AdminListAdminUserRecordsV1
from .admin_post_admin_game_r_e8f678 import AdminPostAdminGameRecordV1
from .admin_post_player_admin_b138ee import AdminPostPlayerAdminRecordV1
from .admin_put_admin_game_record_v1 import AdminPutAdminGameRecordV1
from .admin_put_admin_player__6ed45f import AdminPutAdminPlayerRecordV1
from .bulk_get_admin_player_r_e53570 import BulkGetAdminPlayerRecordByUserIdsV1



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Browser Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsGameSessionSetting(Model):
    """Models game session setting (models.GameSessionSetting)

    Properties:
        allow_join_in_progress: (allow_join_in_progress) REQUIRED bool

        current_internal_player: (current_internal_player) REQUIRED int

        current_player: (current_player) REQUIRED int

        map_name: (map_name) REQUIRED str

        max_internal_player: (max_internal_player) REQUIRED int

        max_player: (max_player) REQUIRED int

        mode: (mode) REQUIRED str

        num_bot: (num_bot) REQUIRED int

        password: (password) REQUIRED str

        settings: (settings) OPTIONAL Dict[str, Any]
    """

    # region fields

    allow_join_in_progress: bool  # REQUIRED
    current_internal_player: int  # REQUIRED
    current_player: int  # REQUIRED
    map_name: str  # REQUIRED
    max_internal_player: int  # REQUIRED
    max_player: int  # REQUIRED
    mode: str  # REQUIRED
    num_bot: int  # REQUIRED
    password: str  # REQUIRED
    settings: Dict[str, Any]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_allow_join_in_progress(self, value: bool) -> ModelsGameSessionSetting:
        self.allow_join_in_progress = value
        return self

    def with_current_internal_player(self, value: int) -> ModelsGameSessionSetting:
        self.current_internal_player = value
        return self

    def with_current_player(self, value: int) -> ModelsGameSessionSetting:
        self.current_player = value
        return self

    def with_map_name(self, value: str) -> ModelsGameSessionSetting:
        self.map_name = value
        return self

    def with_max_internal_player(self, value: int) -> ModelsGameSessionSetting:
        self.max_internal_player = value
        return self

    def with_max_player(self, value: int) -> ModelsGameSessionSetting:
        self.max_player = value
        return self

    def with_mode(self, value: str) -> ModelsGameSessionSetting:
        self.mode = value
        return self

    def with_num_bot(self, value: int) -> ModelsGameSessionSetting:
        self.num_bot = value
        return self

    def with_password(self, value: str) -> ModelsGameSessionSetting:
        self.password = value
        return self

    def with_settings(self, value: Dict[str, Any]) -> ModelsGameSessionSetting:
        self.settings = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "allow_join_in_progress"):
            result["allow_join_in_progress"] = bool(self.allow_join_in_progress)
        elif include_empty:
            result["allow_join_in_progress"] = False
        if hasattr(self, "current_internal_player"):
            result["current_internal_player"] = int(self.current_internal_player)
        elif include_empty:
            result["current_internal_player"] = 0
        if hasattr(self, "current_player"):
            result["current_player"] = int(self.current_player)
        elif include_empty:
            result["current_player"] = 0
        if hasattr(self, "map_name"):
            result["map_name"] = str(self.map_name)
        elif include_empty:
            result["map_name"] = ""
        if hasattr(self, "max_internal_player"):
            result["max_internal_player"] = int(self.max_internal_player)
        elif include_empty:
            result["max_internal_player"] = 0
        if hasattr(self, "max_player"):
            result["max_player"] = int(self.max_player)
        elif include_empty:
            result["max_player"] = 0
        if hasattr(self, "mode"):
            result["mode"] = str(self.mode)
        elif include_empty:
            result["mode"] = ""
        if hasattr(self, "num_bot"):
            result["num_bot"] = int(self.num_bot)
        elif include_empty:
            result["num_bot"] = 0
        if hasattr(self, "password"):
            result["password"] = str(self.password)
        elif include_empty:
            result["password"] = ""
        if hasattr(self, "settings"):
            result["settings"] = {str(k0): v0 for k0, v0 in self.settings.items()}
        elif include_empty:
            result["settings"] = {}
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        allow_join_in_progress: bool,
        current_internal_player: int,
        current_player: int,
        map_name: str,
        max_internal_player: int,
        max_player: int,
        mode: str,
        num_bot: int,
        password: str,
        settings: Optional[Dict[str, Any]] = None,
        **kwargs,
    ) -> ModelsGameSessionSetting:
        instance = cls()
        instance.allow_join_in_progress = allow_join_in_progress
        instance.current_internal_player = current_internal_player
        instance.current_player = current_player
        instance.map_name = map_name
        instance.max_internal_player = max_internal_player
        instance.max_player = max_player
        instance.mode = mode
        instance.num_bot = num_bot
        instance.password = password
        if settings is not None:
            instance.settings = settings
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsGameSessionSetting:
        instance = cls()
        if not dict_:
            return instance
        if (
            "allow_join_in_progress" in dict_
            and dict_["allow_join_in_progress"] is not None
        ):
            instance.allow_join_in_progress = bool(dict_["allow_join_in_progress"])
        elif include_empty:
            instance.allow_join_in_progress = False
        if (
            "current_internal_player" in dict_
            and dict_["current_internal_player"] is not None
        ):
            instance.current_internal_player = int(dict_["current_internal_player"])
        elif include_empty:
            instance.current_internal_player = 0
        if "current_player" in dict_ and dict_["current_player"] is not None:
            instance.current_player = int(dict_["current_player"])
        elif include_empty:
            instance.current_player = 0
        if "map_name" in dict_ and dict_["map_name"] is not None:
            instance.map_name = str(dict_["map_name"])
        elif include_empty:
            instance.map_name = ""
        if "max_internal_player" in dict_ and dict_["max_internal_player"] is not None:
            instance.max_internal_player = int(dict_["max_internal_player"])
        elif include_empty:
            instance.max_internal_player = 0
        if "max_player" in dict_ and dict_["max_player"] is not None:
            instance.max_player = int(dict_["max_player"])
        elif include_empty:
            instance.max_player = 0
        if "mode" in dict_ and dict_["mode"] is not None:
            instance.mode = str(dict_["mode"])
        elif include_empty:
            instance.mode = ""
        if "num_bot" in dict_ and dict_["num_bot"] is not None:
            instance.num_bot = int(dict_["num_bot"])
        elif include_empty:
            instance.num_bot = 0
        if "password" in dict_ and dict_["password"] is not None:
            instance.password = str(dict_["password"])
        elif include_empty:
            instance.password = ""
        if "settings" in dict_ and dict_["settings"] is not None:
            instance.settings = {str(k0): v0 for k0, v0 in dict_["settings"].items()}
        elif include_empty:
            instance.settings = {}
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsGameSessionSetting]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsGameSessionSetting]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsGameSessionSetting,
        List[ModelsGameSessionSetting],
        Dict[Any, ModelsGameSessionSetting],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "allow_join_in_progress": "allow_join_in_progress",
            "current_internal_player": "current_internal_player",
            "current_player": "current_player",
            "map_name": "map_name",
            "max_internal_player": "max_internal_player",
            "max_player": "max_player",
            "mode": "mode",
            "num_bot": "num_bot",
            "password": "password",
            "settings": "settings",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "allow_join_in_progress": True,
            "current_internal_player": True,
            "current_player": True,
            "map_name": True,
            "max_internal_player": True,
            "max_player": True,
            "mode": True,
            "num_bot": True,
            "password": True,
            "settings": False,
        }

    # endregion static methods
